@@ -60,8 +60,10 @@ void ntp_RAND_priv_bytes(unsigned char *buf, int num);
  * NTP protocol parameters.  See section 3.2.6 of the specification.
  */
 #define	NTP_VERSION	4	/* current version number */
-#define	NTP_OLDVERSION	1 	/* oldest credible version */
+#define	NTP_OLDVERSION	1 	/* oldest credible version: see #707 */
+#define	NTPv1		1 	/* Gets special treatment: see receive() */
 #define	NTP_PORT	123	/* included for non-unix machines */
+#define	NTP_PORTA	"123"	/* or unix without /etc/services */
 
 /* pythonize-header: start ignoring */
 
@@ -141,11 +143,9 @@ typedef struct netendpt {
 	SOCKET		fd;		/* socket descriptor */
 	uint32_t	ifnum;		/* endpt instance count */
 	sockaddr_u	sin;		/* unicast address */
-	sockaddr_u	mask;		/* subnet mask */
-	sockaddr_u	bcast;		/* broadcast address */
 	char		name[32];	/* name of interface */
 	unsigned short	family;		/* AF_INET/AF_INET6 */
-	unsigned short	phase;		/* phase in update cycle */
+	bool		inuse;		/* needed to drop unused */
 	uint32_t	flags;		/* interface flags */
 	refid_t		addr_refid;	/* IPv4 addr or IPv6 hash */
 	unsigned long	starttime;	/* current_time at creation */
@@ -153,7 +153,7 @@ typedef struct netendpt {
 	long		sent;		/* number of outgoing packets */
 	long		notsent;	/* number of send failures */
 	unsigned int	ifindex;	/* for IPV6_MULTICAST_IF */
-	bool	ignore_packets; /* listen-read-drop this? */
+	bool		ignore_packets; /* listen-read-drop this? */
 	struct peer *	peers;		/* list of peers using endpt */
 	unsigned int	peercnt;	/* count of same */
 } endpt;
@@ -163,15 +163,15 @@ typedef struct netendpt {
  * in Mode 6 ifstats reports.
  */
 #define INT_UP		0x001	/* Interface is up */
-#define	INT_PPP		0x002	/* Point-to-point interface */
+/* #define	INT_PPP		0x002	** Point-to-point interface */
 #define	INT_LOOPBACK	0x004U	/* the loopback interface */
-#define	INT_BROADCAST	0x008	/* can broadcast out this interface */
+/* #define	INT_BROADCAST	0x008	** can broadcast out this interface */
 /* #define INT_MULTICAST	0x010	** can multicast out this interface */
-#define	INT_BCASTOPEN	0x020U	/* broadcast receive socket is open */
+/* #define	INT_BCASTOPEN	0x020U	** broadcast receive socket is open */
 /* #define INT_MCASTOPEN	0x040	** multicasting enabled */
 #define INT_WILDCARD	0x080	/* wildcard interface - usually skipped */
-#define INT_MCASTIF	0x100	/* bound directly to MCAST address */
-#define INT_PRIVACY	0x200	/* RFC 4941 IPv6 privacy address */
+/* #define INT_MCASTIF	0x100	** bound directly to MCAST address */
+/* #define INT_PRIVACY	0x200	** RFC 4941 IPv6 privacy address */
 /* #define INT_BCASTXMIT	0x400   ** socket setup to allow broadcasts */
 
 /*
@@ -209,15 +209,16 @@ struct peer_ctl {
 #define BOGON5		0x0010	/* bad authentication */
 #define BOGON6		0x0020	/* bad synch or stratum */
 #define BOGON7		0x0040	/* bad header */
-#define BOGON8		0x0080  /* bad autokey */
-#define BOGON9		0x0100	/* bad crypto */
+#define BOGON8x		0x0080  /* bad autokey -- not used */
+#define BOGON9x		0x0100	/* bad crypto -- not used */
+#define BOGON14		0x2000	/* response took too long */
 #define	PKT_BOGON_MASK	(BOGON1 | BOGON2 | BOGON3 | BOGON4 | BOGON5 |\
-			BOGON6 | BOGON7 | BOGON8 | BOGON9)
+			BOGON6 | BOGON7 | BOGON14)
 /*
  * Peer errors
  */
 #define BOGON10		0x0200	/* peer bad synch or stratum */
-#define	BOGON11		0x0400	/* peer distance exceeded */
+#define BOGON11		0x0400	/* peer distance exceeded */
 #define BOGON12		0x0800	/* peer synchronization loop */
 #define BOGON13		0x1000	/* peer unreacable */
 #define	PEER_BOGON_MASK	(BOGON10 | BOGON11 | BOGON12 | BOGON13)
@@ -309,12 +310,15 @@ struct peer {
 	double	jitter;		/* peer jitter (squares) */
 	double	disp;		/* peer dispersion */
 
+	unsigned int   outcount;    /* packets sent without reply */
+	unsigned int   bogons;      /* bogus packets recvd since last xmit */
+
+	unsigned long	update;     /* receive epoch */
 	/*
 	 * End of clear-to-zero area
 	 */
-	unsigned int   outcount;       /* packets sent without reply */
-	unsigned long	update;		/* receive epoch */
 #define end_clear_to_zero update
+
 	int	unreach;	/* watchdog counter */
 	int	throttle;	/* rate control */
 	uptime_t	outdate;	/* send time last packet */
@@ -581,7 +585,7 @@ struct pkt {
  * Configuration items for the loop filter
  */
 #define	LOOP_DRIFTINIT		1	/* iniitialize frequency */
-#define	LOOP_KERN_CLEAR		2	/* set initial frequency offset */
+/* #define LOOP_KERN_CLEAR	2	** set initial frequency offset */
 #define LOOP_MAX		3	/* set both step offsets */
 #define LOOP_MAX_BACK		4	/* set bacward-step offset */
 #define LOOP_MAX_FWD		5	/* set forward-step offset */
@@ -622,26 +626,16 @@ struct mon_data {
 };
 
 /*
- * Values for cast_flags in mon_entry and struct peer.  mon_entry uses
- * only MDF_UCAST and MDF_BCAST.
+ * Values for cast_flags in struct peer.
  */
 #define	MDF_UCAST	0x01	/* unicast client */
 /* #define MDF_MCAST	0x02	** multicast server (not used) */
 /* #define MDF_BCAST	0x04	** broadcast server (not used) */
 #define	MDF_POOL	0x08	/* pool client solicitor */
 /* #define MDF_ACAST	0x10	** manycast client solicitor (not used) */
-#define	MDF_BCLNT	0x20	/* eph. broadcast/multicast client */
-#define MDF_UCLNT	0x40	/* preemptible manycast or pool client */
-/*
- * In the context of struct peer in ntpd, one cast_flags bit
- * represent configured associations which never receive packets, and
- * whose reach is always 0: MDF_BCAST  (Historical)
- */
-#define MDF_TXONLY_MASK	(MDF_POOL)
-/*
- * manycastclient-like solicitor association cast_flags bits
- */
-#define MDF_SOLICIT_MASK	MDF_POOL
+/* #define MDF_BCLNT	0x20	** eph. broadcast/multicast client */
+/* #define MDF_UCLNT	0x40	** preemptible manycast or pool client */
+
 /*
  * Values used with mon_enabled to indicate reason for enabling monitoring
  */
@@ -664,10 +658,9 @@ typedef struct res_addr6_tag {
 typedef struct restrict_u_tag	restrict_u;
 struct restrict_u_tag {
 	restrict_u *		link;	/* link to next entry */
-	uint32_t		hitcount;	/* number of packets matched */
+	uint64_t		hitcount;	/* number of packets matched */
 	unsigned short		flags;	/* accesslist flags */
 	unsigned short		mflags;	/* match flags */
-	unsigned long		expire;	/* valid until time */
 	union {				/* variant starting here */
 		res_addr4 v4;
 		res_addr6 v6;
@@ -685,26 +678,22 @@ struct restrict_u_tag {
  * through the Mode 6 protocol.
  */
 #define	RES_IGNORE		0x0001	/* ignore packet */
-#define	RES_DONTSERVE		0x0002	/* access denied */
-#define	RES_DONTTRUST		0x0004	/* authentication required */
+#define	RES_NOSERVE		0x0002	/* access denied */
+#define	RES_NOTRUST		0x0004	/* authentication required */
 #define	RES_VERSION		0x0008	/* version mismatch */
-#define	RES_NOPEER		0x0010	/* new association denied */
-#define RES_LIMITED		0x0020	/* packet rate exceeded */
-#define RES_FLAGS		(RES_IGNORE | RES_DONTSERVE |\
-				    RES_DONTTRUST | RES_VERSION |\
-				    RES_NOPEER | RES_LIMITED)
+#define	RES_NOPEERx		0x0010  /* new association denied */
+#define	RES_LIMITED		0x0020	/* packet rate exceeded */
 
 #define	RES_NOQUERY		0x0040	/* mode 6 packet denied */
 #define	RES_NOMODIFY		0x0080	/* mode 6 modify denied */
-#define	RES_NOTRAP		0x0100	/* mode 6 set trap denied (not used) */
-#define	RES_LPTRAP		0x0200	/* mode 6 low priority trap (not used) */
+#define	RES_NOTRAPx		0x0100	/* mode 6 set trap denied (not used) */
+#define	RES_LPTRAPx		0x0200	/* mode 6 low priority trap (not used) */
 
 #define	RES_KOD			0x0400	/* send kiss of death packet */
 #define	RES_MSSNTP		0x0800	/* enable MS-SNTP authentication */
 #define	RES_FLAKE		0x1000	/* flakeway - drop 10% */
 #define	RES_NOMRULIST		0x2000	/* mode 6 mrulist denied */
 
-/* RES_DEFAULT defined in resolv.h */
 #define RES_Default (RES_NOQUERY|RES_LIMITED)
 
 /* pythonize-header: start ignoring */
