@@ -1,8 +1,9 @@
 /*
  * ntp_control.h - definitions related to NTP mode 6 control messages
  *
- * mode 6 messages are defined in:
- * https://datatracker.ietf.org/doc/draft-ietf-ntp-mode-6-cmds/
+ * mode 6 messages are defined in RFC 9327
+ *  Control Messages Protocol for Use with Network Time Protocol Version 4
+ *  https://www.rfc-editor.org/rfc/rfc9327.pdf
  *
  */
 #ifndef GUARD_NTP_CONTROL_H
@@ -11,11 +12,11 @@
 #include "ntp_types.h"
 
 /* The attribute after this structure is a gcc/clang extension that forces
- * the beginning of a structure instance to be 32-bit aligned.  Without this
- * attempting to compile on a 32-bit host may throw warnings or errors when
- * a pointer to this structure is passed to authdecrypt/authencrypt, both of
- * which expect to be able to treat the structure as an array of uint32_t
- * elements.  Ideally, we'd get rid of that nasty type punning. */
+ * the beginning of a structure instance to be 32-bit aligned.  Without this,
+ * attempting to compile on an alignment-sensitive host may throw warnings or
+ * errors when a pointer to this structure is passed to authdecrypt/authencrypt,
+ * both of which expect to be able to treat the structure as an array of
+ * uint32_t elements.  Ideally, we'd get rid of that nasty type punning. */
 struct ntp_control {
 	uint8_t li_vn_mode;		/* leap, version, mode */
 	uint8_t r_m_e_op;		/* response, more, error, opcode */
@@ -26,7 +27,7 @@ struct ntp_control {
         /* the draft RFC says 0 <= count <= 468 */
 	uint16_t count;			/* byte count of data in this packet */
 	uint8_t data[480 + MAX_MAC_LEN]; /* data + padding + auth */
-} __attribute__((aligned(32)));
+} __attribute__((aligned(4)));
 
 /*
  * Length of the control header, in octets
@@ -56,13 +57,14 @@ struct ntp_control {
 #define	CTL_OP_WRITEVAR		3	/* write variables */
 #define	CTL_OP_READCLOCK	4	/* read clock variables */
 #define	CTL_OP_WRITECLOCK	5	/* write clock variables */
-#define	CTL_OP_SETTRAP		6	/* set trap address (obsolete, unused) */
-#define	CTL_OP_ASYNCMSG		7	/* asynchronous message */
+/* #def	CTL_OP_SETTRAP		6	** set trap address (unused) */
+/* #def	CTL_OP_ASYNCMSG		7	** trap message (unused) */
 #define CTL_OP_CONFIGURE	8	/* runtime configuration */
+/* #def	CTL_OP_EXCONFIG		9	**  export config to file (unused) */
 #define CTL_OP_READ_MRU		10	/* retrieve MRU (mrulist) */
 #define CTL_OP_READ_ORDLIST_A	11	/* ordered list req. auth. */
 #define CTL_OP_REQ_NONCE	12	/* request a client nonce */
-#define	CTL_OP_UNSETTRAP	31	/* unset trap (obsolete, unused) */
+/* #def	CTL_OP_UNSETTRAP	31	** unset trap (unused) */
 
 /*
  * {En,De}coding of the system status word
@@ -98,7 +100,7 @@ struct ntp_control {
 #define	CTL_PST_AUTHENABLE	0x40
 #define	CTL_PST_AUTHENTIC	0x20
 #define	CTL_PST_REACH		0x10
-#define	CTL_PST_BCAST		0x08
+#define	CTL_PST_BCASTx		0x08
 
 #define	CTL_PST_SEL_REJECT	0	/*   reject */
 #define	CTL_PST_SEL_SANE	1	/* x falsetick */
@@ -162,7 +164,7 @@ struct ntp_control {
  * IFSTATS_FIELDS is the number of fields ntpd supplies for each ifstats
  * row.  Similarly RESLIST_FIELDS for reslist.
  */
-#define	IFSTATS_FIELDS	12
+#define	IFSTATS_FIELDS	9
 #define	RESLIST_FIELDS	4
 
 /*
