@@ -14,10 +14,10 @@
 
 #include "ntp_malloc.h"
 
-typedef union {
-	struct sockaddr		sa;
-	struct sockaddr_in	sa4;
-	struct sockaddr_in6	sa6;
+typedef union {				/* On Linux, these come from: */
+	struct sockaddr		sa;	/* /usr/include/bits/socket.h */
+	struct sockaddr_in	sa4;	/* /usr/include/linux/in.h */
+	struct sockaddr_in6	sa6;	/* /usr/include/linux/in6.h */
 } sockaddr_u;
 
 /*
@@ -178,16 +178,6 @@ typedef union {
 #define SOCK_UNSPEC_S(psau)					\
 	(SOCK_UNSPEC(psau) && !SCOPE(psau))
 
-/* choose a default net interface (endpt) for v4 or v6 */
-#define ANY_INTERFACE_BYFAM(family)				\
-	((AF_INET == family)					\
-	     ? any_interface					\
-	     : any6_interface)
-
-/* choose a default interface for addresses' protocol (addr family) */
-#define ANY_INTERFACE_CHOOSE(psau)				\
-	ANY_INTERFACE_BYFAM(AF(psau))
-
 
 /*
  * Macro for checking for invalid addresses.  This is really, really
