@@ -1,7 +1,11 @@
-/* Copyright (c) 2017-2019 Akamai Technologies, Inc.
+/* Copyright Akamai Technologies, Inc.
  * SPDX-License-Identifier: Apache-2.0
  */
 
+/* Hack to supress a blizzard of warnings when built on OpenSSL 3
+ * Drop this patch when upstream is fixed. */
+#define OPENSSL_SUPPRESS_DEPRECATED 1
+
 #define _POSIX_C_SOURCE 200112L
 #define _ISOC99_SOURCE 1
 
@@ -77,7 +81,7 @@ static void debug(const char *label, const unsigned char *hex, size_t len) {
                 if (i > 0 && i % 16 == 0) {
                         printf("\n                  ");
                 }
-                printf("%.2x", (int)hex[i]);
+                printf("%.2x", (unsigned int)hex[i]);
                 if (i > 0 && i % 4 == 3) {
                         printf(" ");
                 }
@@ -247,12 +251,12 @@ void AES_SIV_CTX_free(AES_SIV_CTX *ctx) {
                         CMAC_CTX_free(ctx->cmac_ctx);
                 }
 		OPENSSL_cleanse(&ctx->d, sizeof ctx->d);
-                free(ctx);
+                OPENSSL_free(ctx);
         }
 }
 
 AES_SIV_CTX *AES_SIV_CTX_new(void) {
-        AES_SIV_CTX *ctx = malloc(sizeof(struct AES_SIV_CTX_st));
+        AES_SIV_CTX *ctx = OPENSSL_malloc(sizeof(struct AES_SIV_CTX_st));
         if (UNLIKELY(ctx == NULL)) {
                 return NULL;
         }
