@@ -7,7 +7,9 @@
 
 #include "config.h"
 
+#include <limits.h>
 #include <sys/types.h>
+#include <time.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
@@ -28,7 +30,17 @@ static FILE *	syslog_file;
 static char *	syslog_fname;
 static char *	syslog_abs_fname;
 
+#ifdef DEBUG
 int		debug;
+#endif // DEBUG
+
+/* Counters */
+struct log_counters {   /* LOG_EMERG, LOG_ALERT, LOG_CRIT not used */
+  uint64_t errors;      /* LOG_ERR */
+  uint64_t warnings;    /* LOG_WARNING */
+  uint64_t others;      /* LOG_NOTICE, LOG_INFO, and LOG_DEBUG */
+};
+struct log_counters log_cnt;
 
 /* libntp default ntp_syslogmask is all bits lit */
 #define INIT_NTP_SYSLOGMASK	~(uint32_t)0
@@ -185,6 +197,65 @@ msyslog(
 	char	buf[1024];
 	va_list	ap;
 
+	switch (level) {
+		case LOG_ERR:
+			log_cnt.errors++;
+			break;
+		case LOG_WARNING:
+			log_cnt.warnings++;
+			break;
+		case LOG_NOTICE:	/* FALLTHROUGH */
+		case LOG_INFO:		/* FALLTHROUGH */
+		case LOG_DEBUG:
+			log_cnt.others++;
+			break;
+		default:
+			break;
+	}
+
+	va_start(ap, fmt);
+	vsnprintf(buf, sizeof(buf), fmt, ap);
+	va_end(ap);
+	addto_syslog(level, buf);
+}
+
+
+/*
+  Do we log this sundry error?
+*/
+void
+maybe_log(
+	struct do_we_log *maybe,
+	int		level,
+	const char *	fmt,
+	...
+	)
+{
+	struct timespec now;	/* time of current attempted print */
+	char	buf[PIPE_BUF];
+	va_list	ap;
+
+	if (NULL != maybe) {
+		clock_gettime(CLOCK_MONOTONIC, &now);
+		if (0 == maybe->last) {
+			/* first time */
+			maybe->last = now.tv_sec;
+		} else {
+			time_t interval_fp = now.tv_sec - maybe->last;
+			double since_last = ((double)interval_fp)/3600.0;
+			maybe->last = now.tv_sec;
+			maybe->score *= exp(-since_last/maybe->c_decay);
+			if (maybe->c_limit < maybe->score) {
+				return;
+			}
+		}
+		maybe->score += 1.0/maybe->c_decay;  /* only count the ones we print */
+#if (1)  // Do we reject logging attempts when argument 0 is NULL?
+	} else {
+		return;
+#endif
+	}
+
 	va_start(ap, fmt);
 	vsnprintf(buf, sizeof(buf), fmt, ap);
 	va_end(ap);
@@ -360,6 +431,17 @@ change_logfile(
 	}
 	syslogit = false;
 
+	/* This leaves something in the log file if you have errors
+	 * parsing ntp.conf and you switch to a log file.
+	 * Maybe this should happen only during initialization.
+	 *   two places: command line and ntp.conf
+	 */ 
+	if (0<log_cnt.errors || 0<log_cnt.warnings) {
+		msyslog(log_cnt.errors? LOG_ERR: LOG_WARNING,
+		"LOG: %lu errors and %lu warnings in previous log file(s)",
+		(unsigned long)log_cnt.errors, (unsigned long)log_cnt.warnings);
+	}
+
 	return 0;
 }
 
@@ -401,14 +483,14 @@ setup_logfile(
 }
 
 /*
- * reopen_logfile()
+ * check_logfile()
  *
  * reopen current logfile in case the old file has been renamed by logrotate
- *
+ * called on SIGHUP and hourly
  */
 
 void
-reopen_logfile(void)
+check_logfile(void)
 {
 	FILE *  new_file;
 
@@ -418,7 +500,7 @@ reopen_logfile(void)
 
 	new_file = fopen(syslog_fname, "a");
 	if (NULL == new_file) {
-		msyslog(LOG_ERR, "LOG: reopen_logfile: couldn't open %s %s",
+		msyslog(LOG_ERR, "LOG: check_logfile: couldn't open %s %s",
                         syslog_fname, strerror(errno));
 		return;
 	}
@@ -431,16 +513,14 @@ reopen_logfile(void)
 	 * This seems to work.
 	 */
 	if (ftell(syslog_file) == ftell(new_file)) {
-		/* just for debugging */
-		msyslog(LOG_INFO, "LOG: reopen_logfile: same length, ignored");
 		fclose(new_file);
 		return;
 	}
 
-	msyslog(LOG_INFO, "LOG: reopen_logfile: closing old file");
+	msyslog(LOG_INFO, "LOG: check_logfile: closing old file");
 	fclose(syslog_file);
 	syslog_file = new_file;
-	msyslog(LOG_INFO, "LOG: reopen_logfile: using %s", syslog_fname);
+	msyslog(LOG_INFO, "LOG: check_logfile: using %s", syslog_fname);
 }
 
 /* Hack because there are 2 APIs to strerror_r()  */
