@@ -1,8 +1,8 @@
 /*
  * ntp_calendar.c - calendar and helper functions
  *
- * Written by Juergen Perlinger <perlinger@ntp.org> for the NTP project.
- * Copyright 2015 by the NTPsec project contributors
+ * Copyright Juergen Perlinger <perlinger@ntp.org> for the NTP project.
+ * Copyright the NTPsec project contributors
  * SPDX-License-Identifier: NTP
  *
  * There is more about these types and calculations in the internals tour
@@ -15,6 +15,7 @@
 #include "ntp_calendar.h"
 #include "ntp_stdlib.h"
 #include "ntp_fp.h"
+#include "PIVOT.h"
 
 /*
  *---------------------------------------------------------------------
@@ -33,12 +34,12 @@ ntpcal_edate_to_yeardays(int32_t, int32_t, int32_t);
  * Get the build date & time
  *---------------------------------------------------------------------
  */
-int
+bool
 ntpcal_get_build_date(
 	struct calendar * jd
 	)
 {
-        time_t epoch = (time_t)BUILD_EPOCH;
+        time_t epoch = RELEASE_DATE;
         struct tm epoch_tm;
 
 	ZERO(*jd);
@@ -673,7 +674,7 @@ ntpcal_days_in_months(
 		res.lo -= 2;
 	}
 
-	/* get cummulated days in year with unshift */
+	/* get cumulated days in year with unshift */
 	res.lo = shift_month_table[res.lo] - 306;
 
 	return res;
