@@ -7,12 +7,6 @@
 #include "ntp_syslog.h"
 #include "ntp_stdlib.h"
 
-# ifdef SA_RESTART
-#  define Z_SA_RESTART		SA_RESTART
-# else
-#  define Z_SA_RESTART		0
-# endif
-
 /* set an sa_handler */
 void
 signal_no_reset(
@@ -27,25 +21,18 @@ signal_no_reset(
 	sigemptyset(&vec.sa_mask);
 	vec.sa_handler = func;
 
-	/* Added for PPS clocks on Solaris 7 which get EINTR errors */
-# ifdef SIGPOLL
-	if (SIGPOLL == sig)
-		vec.sa_flags = Z_SA_RESTART;
-# endif
-# ifdef SIGIO
-	if (SIGIO == sig)
-		vec.sa_flags = Z_SA_RESTART;
-# endif
-
-	do
-		n = sigaction(sig, &vec, NULL);
-	while (-1 == n && EINTR == errno);
+	n = sigaction(sig, &vec, NULL);
 	if (-1 == n) {
 		perror("ERROR: signal_no_reset() sigaction");
 		exit(1);
 	}
 }
 
+#ifndef __NetBSD__
+/* NetBSD 10.0, May 2024, barfs when it can't find siginfo_t ???
+ * There is a similar test in include/ntp_stdlib.h
+ * This is only used by ntp_sandbox inside an ifdef for HAVE_SECCOMP_H */
+
 /* set an sa_sigaction */
 void
 signal_no_reset1(
@@ -67,3 +54,5 @@ signal_no_reset1(
 		exit(1);
 	}
 }
+#endif
+
