@@ -1,7 +1,10 @@
 /*
  * timespecops.h -- calculations on 'struct timespec' values
  *
- * Written by Juergen Perlinger (perlinger@ntp.org) for the NTP project.
+ * Copyright Juergen Perlinger (perlinger@ntp.org)
+ * Copyright the NTPsec project contributors
+ * SPDX-License-Identifier: NTP
+
  *
  * Rationale
  * ---------
@@ -34,8 +37,6 @@
  * Input and output operands may overlap; all input is consumed before
  * the output is written to.
  *
- * Copyright 2015 by the NTPsec project contributors
- * SPDX-License-Identifier: NTP
  */
 #include "config.h"
 
@@ -45,7 +46,6 @@
 #include "timespecops.h"
 #include "ntp.h"
 #include "ntp_calendar.h"
-#include "timetoa.h"
 
 /* make sure nanoseconds are in nominal range */
 struct timespec
@@ -104,6 +104,17 @@ d_to_tspec(
 	return x;
 }
 
+/* convert a timespec to a double
+ * will drop low bits if integer part is big
+ */
+double
+tspec_to_d(
+	struct timespec ts
+	)
+{
+	return (ts.tv_sec + ts.tv_nsec*S_PER_NS);
+}
+
 /* x = a + b */
 struct timespec
 add_tspec(
@@ -349,12 +360,12 @@ lfp_stamp_to_tspec(
 	sec = ntpcal_ntp_to_time(lfpuint(x), p);
 	out.tv_nsec = FTOTVN(lfpfrac(x));
 
-	/* copying a time64_t to a time_t needs some care... */
-#if NTP_SIZEOF_TIME_T <= 4
-	out.tv_sec = (time_t)time64lo(sec);
-#else
-	out.tv_sec = (time_t)time64s(sec);
-#endif
+        // copying a time64_t to a time_t needs some care...
+        if (4 >= sizeof(time_t)) {
+            out.tv_sec = (time_t)time64lo(sec);
+        } else {
+            out.tv_sec = (time_t)time64s(sec);
+        }
 
 	return out;
 }
