@@ -1,6 +1,10 @@
 #! @PYSHEBANG@
 # -*- coding: utf-8 -*-
 
+# Copyright the NTPsec project contributors
+#
+# SPDX-License-Identifier: BSD-2-Clause
+
 """\
 usage: ntplogtemp [-h] [-l LOGFILE] [-o] [-q] [-v] [-w WAIT] [-V]
 
@@ -126,6 +130,8 @@ class SmartCtl:
             # Which drive to watch
             for child in glob.glob('/dev/sd?'):
                 self._drives.append(child)
+            for child in glob.glob('/dev/nvme?n?'):
+                self._drives.append(child)
             self._drives = sorted(self._drives)
 
     def get_data(self):
@@ -146,6 +152,12 @@ class SmartCtl:
                         now = int(time.time())
                         temp = line.split()[9]
                         data.append('%d %s %s' % (now, _device, temp))
+                        break
+                    if line.startswith('Temperature:'):
+                        now = int(time.time())
+                        temp = line.split()[1]
+                        data.append('%d %s %s' % (now, _device, temp))
+                        break
         return data
 
 
@@ -207,13 +219,16 @@ class ZoneTemp:
         _zone = 0
         _data = []
         for zone in self.zones:
-            _zone_data = open(os.path.join(zone, 'temp'))
-            for line in _zone_data:
-                temp = float(line) / 1000
-                _now = int(time.time())
-                _data.append('%d ZONE%s %s' % (_now, _zone, temp))
-                _zone += 1
-            _zone_data.close()
+            try:
+                with open(os.path.join(zone, 'temp')) as _zone_data:
+                    for line in _zone_data:
+                        temp = float(line) / 1000
+                        _now = int(time.time())
+                        _data.append('%d ZONE%s %s' % (_now, _zone, temp))
+                        _zone += 1
+            except OSError:
+                # temp might not be readable, if so continue on to the next one
+                continue
         return _data
 
 
