@@ -35,9 +35,9 @@ struct key_tok ntp_keywords[] = {
 { "dscp",		T_Dscp,			FOLLBY_TOKEN },
 { "enable",		T_Enable,		FOLLBY_TOKEN },
 { "end",		T_End,			FOLLBY_TOKEN },
+{ "extra",		T_Extra,		FOLLBY_TOKEN },
 { "filegen",		T_Filegen,		FOLLBY_TOKEN },
 { "fudge",		T_Fudge,		FOLLBY_STRING },
-{ "holdover",		T_Holdover,		FOLLBY_TOKEN },
 { "io",			T_Io,			FOLLBY_TOKEN },
 { "includefile",	T_Includefile,		FOLLBY_STRING },
 { "leapfile",		T_Leapfile,		FOLLBY_STRING },
@@ -50,8 +50,8 @@ struct key_tok ntp_keywords[] = {
 { "phone",		T_Phone,		FOLLBY_STRINGS_TO_EOC },
 { "pidfile",		T_Pidfile,		FOLLBY_STRING },
 { "pool",		T_Pool,			FOLLBY_STRING },
+{ "port",		T_Port,			FOLLBY_TOKEN },
 { "ppspath",		T_Ppspath,		FOLLBY_STRING },
-{ "discard",		T_Discard,		FOLLBY_TOKEN },
 { "reset",		T_Reset,		FOLLBY_TOKEN },
 { "restrict",		T_Restrict,		FOLLBY_TOKEN },
 { "refclock",		T_Refclock,		FOLLBY_STRING },
@@ -100,6 +100,8 @@ struct key_tok ntp_keywords[] = {
 { "rawstats",		T_Rawstats,		FOLLBY_TOKEN },
 { "sysstats", 		T_Sysstats,		FOLLBY_TOKEN },
 { "usestats",		T_Usestats,		FOLLBY_TOKEN },
+{ "ntsstats",		T_Ntsstats,		FOLLBY_TOKEN },
+{ "ntskestats",		T_Ntskestats,		FOLLBY_TOKEN },
 /* filegen_option */
 { "file",		T_File,			FOLLBY_STRING },
 { "link",		T_Link,			FOLLBY_TOKEN },
@@ -131,6 +133,7 @@ struct key_tok ntp_keywords[] = {
 { "source",		T_Source,		FOLLBY_TOKEN },
 { "flake",		T_Flake,		FOLLBY_TOKEN },
 { "ignore",		T_Ignore,		FOLLBY_TOKEN },
+{ "limit",		T_Limit,		FOLLBY_TOKEN },
 { "limited",		T_Limited,		FOLLBY_TOKEN },
 { "mssntp",		T_Mssntp,		FOLLBY_TOKEN },
 { "kod",		T_Kod,			FOLLBY_TOKEN },
@@ -143,9 +146,8 @@ struct key_tok ntp_keywords[] = {
 { "noserve",		T_Noserve,		FOLLBY_TOKEN },
 { "notrust",		T_Notrust,		FOLLBY_TOKEN },
 { "ntpport",		T_Ntpport,		FOLLBY_TOKEN },
-/* discard_option */
+/* limit_option */
 { "average",		T_Average,		FOLLBY_TOKEN },
-{ "minimum",		T_Minimum,		FOLLBY_TOKEN },
 { "monitor",		T_Monitor,		FOLLBY_TOKEN },
 /* mru_option */
 { "incalloc",		T_Incalloc,		FOLLBY_TOKEN },
@@ -199,16 +201,14 @@ struct key_tok ntp_keywords[] = {
 { "drop",		T_Drop,			FOLLBY_TOKEN },
 /* NTS */
 { "nts",		T_Nts,			FOLLBY_TOKEN },
-{ "ask",		T_Ask,			FOLLBY_STRING },
-{ "require",		T_Require,		FOLLBY_STRING },
 { "noval",		T_Noval,		FOLLBY_TOKEN },
-{ "expire",		T_Expire,		FOLLBY_TOKEN },
 { "cert",		T_Cert,			FOLLBY_TOKEN },
 { "ca",			T_Ca,			FOLLBY_TOKEN },
 { "mintls",		T_Mintls,		FOLLBY_TOKEN },
 { "maxtls",		T_Maxtls,		FOLLBY_TOKEN },
-{ "tlsciphers",		T_Tlsciphers,		FOLLBY_STRING },
 { "tlsciphersuites",	T_Tlsciphersuites,	FOLLBY_STRING },
+{ "tlsecdhcurves",	T_Tlsecdhcurves,	FOLLBY_STRING },
+{ "tlscipherserverpreference",	T_Tlscipherserverpreference,	FOLLBY_TOKEN },
 };
 
 typedef struct big_scan_state_tag {
