@@ -6,17 +6,13 @@
  *		University of Delaware
  *		Newark, DE 19711
  * Some parts borrowed from the older ntp_config.c
- * Copyright (c) 2006
- * Copyright 2015 by the NTPsec project contributors
+ * Copyright Sachin Kamboj
+ * Copyright the NTPsec project contributors
  * SPDX-License-Identifier: BSD-2-Clause
 */
 
 #include "config.h"
 
-#ifdef HAVE_NETINFO_NI_H
-# include <netinfo/ni.h>
-#endif
-
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
@@ -49,11 +45,6 @@
   int yyparse (void);
 #endif
 
-/* NetInfo configuration locations */
-#ifdef HAVE_NETINFO_NI_H
-#define NETINFO_CONFIG_DIR "/config/ntp"
-#endif
-
 /*
  * Selection algorithm tuning parameters
  */
@@ -84,6 +75,9 @@
 #define REFCLOCKUNIT(srcadr)	(SRCADR(srcadr) & 0xff)
 
 
+/* count of parsing errors - for log file */
+int     parsing_errors = 0;
+
 /* list of servers from command line for config_peers() */
 int	cmdline_server_count = 0;
 char **	cmdline_servers;
@@ -144,11 +138,6 @@ static struct masks logcfg_class_items[] = {
 /*
  * Miscellaneous macros
  */
-#ifdef HAVE_NETINFO_NI_H
-# define ISEOL(c)	((c) == '#' || (c) == '\n' || (c) == '\0')
-# define ISSPACE(c)	((c) == ' ' || (c) == '\t')
-#endif
-
 #define _UC(str)	((char *)(intptr_t)(str))
 
 /*
@@ -165,23 +154,6 @@ static char default_ntp_signd_socket[] =
 					"";
 #endif
 char *ntp_signd_socket = default_ntp_signd_socket;
-#ifdef HAVE_NETINFO_NI_H
-static struct netinfo_config_state *config_netinfo = NULL;
-static bool check_netinfo = true;
-#endif /* HAVE_NETINFO_NI_H */
-
-#ifdef HAVE_NETINFO_NI_H
-/*
- * NetInfo configuration state
- */
-struct netinfo_config_state {
-	void *domain;		/* domain with config */
-	ni_id config_dir;	/* ID config dir      */
-	int prop_index;		/* current property   */
-	int val_index;		/* current value      */
-	char **val_list;	/* value list         */
-};
-#endif
 
 struct REMOTE_CONFIG_INFO remote_config;  /* Remote configuration buffer and
 					     pointer info */
@@ -208,6 +180,7 @@ static void free_config_reset_counters(config_tree *);
 static void free_config_rlimit(config_tree *);
 static void free_config_setvar(config_tree *);
 static void free_config_system_opts(config_tree *);
+static void free_config_extra(config_tree *);
 static void free_config_tinker(config_tree *);
 static void free_config_nts(config_tree *);
 static void free_config_tos(config_tree *);
@@ -266,6 +239,7 @@ static void config_logconfig(config_tree *);
 static void config_monitor(config_tree *);
 static void config_rlimit(config_tree *);
 static void config_system_opts(config_tree *);
+static void config_extra(config_tree *);
 static void config_tinker(config_tree *);
 static void config_nts(config_tree *);
 static void config_tos(config_tree *);
@@ -356,6 +330,7 @@ free_config_tree(
 	free_config_tos(ptree);
 	free_config_monitor(ptree);
 	free_config_access(ptree);
+	free_config_extra(ptree);
 	free_config_tinker(ptree);
 	free_config_nts(ptree);
 	free_config_rlimit(ptree);
@@ -505,9 +480,6 @@ create_attr_sval(
 
 	my_val = emalloc_zero(sizeof(*my_val));
 	my_val->attr = attr;
-	if (NULL == s) {			/* free() hates NULL */
-		s = estrdup("");
-	}
 	my_val->value.s = _UC(s);
 	my_val->type = T_String;
 
@@ -637,8 +609,13 @@ create_peer_node(
 				break;
 
 			case T_Nts:
+#ifdef DISABLE_NTS
+				msyslog(LOG_ERR, "CONFIG: nts not supported");
+				exit(1);
+#else
 				my_node->ctl.flags |= (FLAG_NTS | FLAG_LOOKUP);
 				break;
+#endif
 
 			case T_Prefer:
 				my_node->ctl.flags |= FLAG_PREFER;
@@ -650,10 +627,6 @@ create_peer_node(
 			}
 			break;
 
-		case T_Expire:
-		    my_node->ctl.nts_cfg.expire = option->value.u;
-		    break;
-
 		case T_Aead:
 		    my_node->ctl.nts_cfg.aead = option->value.s;
 		    break;
@@ -662,10 +635,6 @@ create_peer_node(
 		    my_node->ctl.nts_cfg.ca = option->value.s;
 		    break;
 
-		case T_Cert:
-		    my_node->ctl.nts_cfg.cert = option->value.s;
-		    break;
-
 		case T_Minpoll:
 			if (option->value.i < NTP_MINPOLL ) {
 				msyslog(LOG_INFO,
@@ -733,16 +702,6 @@ create_peer_node(
 			my_node->ctl.bias = option->value.d;
 			break;
 
-		case T_Ask:
-			my_node->ctl.flags |= FLAG_NTS_ASK;
-			my_node->ctl.nts_cfg.server = estrdup(option->value.s);
-			break;
-
-		case T_Require:
-			my_node->ctl.flags |= FLAG_NTS_REQ;
-			my_node->ctl.nts_cfg.server = estrdup(option->value.s);
-			break;
-
 #ifdef REFCLOCK
 		case T_Path:
 			my_node->ctl.path = estrdup(option->value.s);
@@ -787,8 +746,18 @@ create_peer_node(
 
 		case T_Flag1:
 			my_node->clock_stat.haveflags |= CLK_HAVEFLAG1;
-			if (option->value.i)
+			if (option->value.i) {
+#ifdef CLOCK_LOCAL
+				/* Ugly hack:
+				 * Need to set loop_data.lockclock early */
+				char * name = my_node->addr->address;
+				if (strstr(name, "127.127.1") == name) {
+				    msyslog(LOG_INFO, "INIT-server: Switching to lockclock mode");
+				    loop_data.lockclock = true;
+				}
+#endif
 				my_node->clock_stat.flags |= CLK_FLAG1;
+			  }
 			else
 				my_node->clock_stat.flags &= ~CLK_FLAG1;
 			break;
@@ -817,9 +786,6 @@ create_peer_node(
 				my_node->clock_stat.flags &= ~CLK_FLAG4;
 			break;
 
-		case T_Holdover:
-			my_node->clock_stat.flags |= CLK_HOLDOVER;
-			break;
 #endif /* REFCLOCK */
 
 		default:
@@ -1269,7 +1235,7 @@ config_tos(
 			break;
 
 		case T_Mindist:
-			item = PROTO_MINDISP;
+			item = PROTO_MINDIST;
 			break;
 
 		case T_Maxdisp:
@@ -1584,41 +1550,35 @@ config_access(
 				keyword(my_opt->attr), my_opt->value.i);
 	}
 
-	/* Configure the discard options */
-	my_opt = HEAD_PFIFO(ptree->discard_opts);
+	/* Configure the limit options */
+	my_opt = HEAD_PFIFO(ptree->limit_opts);
 	for (; my_opt != NULL; my_opt = my_opt->link) {
 
 		switch (my_opt->attr) {
 
-		case T_Average:
-			if (0 <= my_opt->value.i &&
-			    my_opt->value.i <= UCHAR_MAX)
-				rstrct.ntp_minpoll = (uint8_t)my_opt->value.u;
-			else
-				msyslog(LOG_ERR,
-					"CONFIG: discard average %d out of range, ignored.",
-					my_opt->value.i);
-			break;
-
-		case T_Minimum:
-			rstrct.ntp_minpkt = my_opt->value.i;
-			break;
-
-		case T_Monitor:
-			mon_data.mon_age = my_opt->value.i;
-			break;
-
 		default:
-			msyslog(LOG_ERR,
-				"CONFIG: Unknown discard option %s (%d)",
-				keyword(my_opt->attr), my_opt->attr);
-			exit(1);
+			INSIST(0);
+			break;
+
+		case T_Average:
+			mon_data.rate_limit = my_opt->value.d;
+			break;
+
+		case T_Burst:
+			mon_data.decay_time = my_opt->value.d;
+			break;
+
+		case T_Kod:
+			mon_data.kod_limit = my_opt->value.d;
+			break;
+
 		}
 	}
 
 	/* Configure the restrict options */
 	my_node = HEAD_PFIFO(ptree->restrict_opts);
 	for (; my_node != NULL; my_node = my_node->link) {
+		int op;
 		if (ai_list != NULL) {
                         /* we do this here, to not need at every continue */
 			freeaddrinfo(ai_list);
@@ -1673,7 +1633,7 @@ config_access(
 				break;
 
 			case T_Nopeer:
-				flags |= RES_NOPEER;
+				msyslog(LOG_ERR, "CONFIG: restrict nopeer ignored");
 				break;
 
 			case T_Noquery:
@@ -1681,20 +1641,15 @@ config_access(
 				break;
 
 			case T_Noserve:
-				flags |= RES_DONTSERVE;
+				flags |= RES_NOSERVE;
 				break;
 
 			case T_Notrap:
-				/*
-				 * No-op - included for backward compatibility
-				 * with all the world's boilerplate ntp.conf
-				 * files.
-				 */
-				flags |= RES_NOTRAP;
+				msyslog(LOG_ERR, "CONFIG: restrict notrap ignored");
 				break;
 
 			case T_Notrust:
-				flags |= RES_DONTTRUST;
+				flags |= RES_NOTRUST;
 				break;
 
 			case T_Version:
@@ -1722,16 +1677,6 @@ config_access(
 			msyslog(LOG_WARNING, "CONFIG: restrict %s: %s", kod_where, kod_warn);
 		}
 
-		if (RES_NOTRAP & flags) {
-			const char *notrap_where = (my_node->addr)
-					  ? my_node->addr->address
-					  : (mflags & RESM_SOURCE)
-					    ? "source"
-					    : "default";
-
-			msyslog(LOG_WARNING, "CONFIG: restrict %s: notrap keyword is ignored.", notrap_where);
-		}
-
 		ZERO_SOCK(&addr);
 		pai = NULL;
 		restrict_default = false;
@@ -1750,7 +1695,7 @@ config_access(
 				DPRINT(1, ("restrict source template mflags %x flags %x\n",
 					   mflags, flags));
 				hack_restrict(RESTRICT_FLAGS, NULL,
-					      NULL, mflags, flags, 0);
+					      NULL, mflags, flags);
 				continue;
 			}
 		} else {
@@ -1782,7 +1727,7 @@ config_access(
 				hints.ai_socktype = SOCK_DGRAM;
 				hints.ai_family = my_node->addr->type;
 				rc = getaddrinfo(my_node->addr->address,
-						 "ntp", &hints,
+						 NTP_PORTA, &hints,
 						 &ai_list);
 				if (rc) {
 					msyslog(LOG_ERR,
@@ -1818,30 +1763,28 @@ config_access(
 				}
 			}
 		}
+		if (my_node->mode == T_Restrict)
+			op = RESTRICT_FLAGS;
+		else if (my_node->mode == T_Unrestrict
+				&& flags == 0 && mflags == 0)
+			op = RESTRICT_REMOVE;
+		else if (my_node->mode == T_Unrestrict)
+			op = RESTRICT_UNFLAG;
+		else
+			continue;	/* should never happen */
 
 		/* Set the flags */
 		if (restrict_default) {
+			/* default case, do both -4 and -6 */
 			AF(&addr) = AF_INET;
 			AF(&mask) = AF_INET;
-			hack_restrict(RESTRICT_FLAGS, &addr,
-				      &mask, mflags, flags, 0);
+			hack_restrict(op, &addr, &mask, mflags, flags);
 			AF(&addr) = AF_INET6;
 			AF(&mask) = AF_INET6;
 		}
 
 		do {
-			int op;
-			if (my_node->mode == T_Restrict)
-				op = RESTRICT_FLAGS;
-			else if (my_node->mode == T_Unrestrict
-					&& flags == 0 && mflags == 0)
-				op = RESTRICT_REMOVE;
-			else if (my_node->mode == T_Unrestrict)
-				op = RESTRICT_UNFLAG;
-			else
-				continue;	/* should never happen */
-			hack_restrict(op, &addr,
-				      &mask, mflags, flags, 0);
+			hack_restrict(op, &addr, &mask, mflags, flags);
 			if (pai != NULL &&
 			    NULL != (pai = pai->ai_next)) {
 				INSIST(pai->ai_addr != NULL);
@@ -1872,7 +1815,7 @@ free_config_access(
 	)
 {
 	FREE_ATTR_VAL_FIFO(ptree->mru_opts);
-	FREE_ATTR_VAL_FIFO(ptree->discard_opts);
+	FREE_ATTR_VAL_FIFO(ptree->limit_opts);
 	FREE_RESTRICT_FIFO(ptree->restrict_opts);
 }
 
@@ -1915,6 +1858,28 @@ config_rlimit(
 }
 
 
+static void
+config_extra(
+	config_tree *ptree
+	)
+{
+	attr_val *	extra;
+
+	extra = HEAD_PFIFO(ptree->extra);
+	for (; extra != NULL; extra = extra->link) {
+		switch (extra->attr) {
+
+		default:
+			INSIST(0);
+			break;
+
+		case T_Port:
+			extra_port = extra->value.i;
+			break;
+		}
+	}
+}
+
 static void
 config_tinker(
 	config_tree *ptree
@@ -1967,10 +1932,6 @@ config_tinker(
 		case T_Stepout:
 			item = LOOP_MINSTEP;
 			break;
-
-		case T_Tick:
-			item = LOOP_TICK;
-			break;
 		}
 		loop_config(item, tinker->value.d);
 	}
@@ -1988,22 +1949,29 @@ config_nts(
 		switch (nts->attr) {
 
 		default:
+#ifdef DISABLE_NTS
+			msyslog(LOG_ERR, "CONFIG: nts not supported");
+			break;
+#else
 			INSIST(0);
 			break;
-
 		case T_Aead:
+			free((void *)(intptr_t)ntsconfig.aead);
 			ntsconfig.aead = estrdup(nts->value.s);
 			break;
 
 		case T_Ca:
+			free((void *)(intptr_t)ntsconfig.ca);
 			ntsconfig.ca = estrdup(nts->value.s);
 			break;
 
 		case T_Cert:
+			free((void *)(intptr_t)ntsconfig.cert);
 			ntsconfig.cert = estrdup(nts->value.s);
 			break;
 
 		case T_Cookie:
+			free((void *)(intptr_t)ntsconfig.KI);
 			ntsconfig.KI = estrdup(nts->value.s);
 			break;
 
@@ -2016,24 +1984,39 @@ config_nts(
 			break;
 
 		case T_Key:
+			free((void *)(intptr_t)ntsconfig.key);
 			ntsconfig.key = estrdup(nts->value.s);
 			break;
 
 		case T_Maxtls:
+			free((void *)(intptr_t)ntsconfig.maxtls);
 			ntsconfig.maxtls = estrdup(nts->value.s);
 			break;
 
 		case T_Mintls:
+			free((void *)(intptr_t)ntsconfig.mintls);
 			ntsconfig.mintls = estrdup(nts->value.s);
 			break;
 
-		case T_Tlsciphers:
-			ntsconfig.tlsciphers = estrdup(nts->value.s);
+		case T_Port:
+			extra_port = nts->value.i;
+			break;
+
+		case T_Tlscipherserverpreference:
+			free((void *)(intptr_t)ntsconfig.tlscipherserverpreference);
+			ntsconfig.tlscipherserverpreference = true;
 			break;
 
 		case T_Tlsciphersuites:
+			free((void *)(intptr_t)ntsconfig.tlsciphersuites);
 			ntsconfig.tlsciphersuites = estrdup(nts->value.s);
 			break;
+
+		case T_Tlsecdhcurves:
+			free((void *)(intptr_t)ntsconfig.tlsecdhcurves);
+			ntsconfig.tlsecdhcurves = estrdup(nts->value.s);
+			break;
+#endif
 		}
 	}
 }
@@ -2047,6 +2030,15 @@ free_config_rlimit(
 	FREE_ATTR_VAL_FIFO(ptree->rlimit);
 }
 
+static void
+free_config_extra(
+	config_tree *ptree
+	)
+{
+	FREE_ATTR_VAL_FIFO(ptree->extra);
+}
+
+
 static void
 free_config_tinker(
 	config_tree *ptree
@@ -2461,8 +2453,18 @@ config_fudge(
 
 			case T_Flag1:
 				clock_stat.haveflags |= CLK_HAVEFLAG1;
-				if (curr_opt->value.i)
+				if (curr_opt->value.i) {
+#ifdef CLOCK_LOCAL
+					/* Ugly hack:
+					 * Need to set loop_data.lockclock early */
+					char * name = addr_node->address;
+					if (strstr(name, "127.127.1") == name) {
+					    msyslog(LOG_INFO, "INIT-fudge: Switching to lockclock mode");
+					    loop_data.lockclock = true;
+					}
+#endif
 					clock_stat.flags |= CLK_FLAG1;
+				}
 				else
 					clock_stat.flags &= ~CLK_FLAG1;
 				break;
@@ -2537,6 +2539,8 @@ config_logfile(
 				msyslog(LOG_ERR,
 					"CONFIG: Cannot open logfile %s: %s",
 					curr_var->value.s, strerror(errno));
+			/* Repeat critical info in logfile. Helps debugging. */
+			announce_starting();
 			break;
 
 		default:
@@ -2558,10 +2562,6 @@ config_vars(
 		/* Determine which variable to set and set it */
 		switch (curr_var->attr) {
 
-		case T_Tick:
-			loop_config(LOOP_TICK, curr_var->value.d);
-			break;
-
 		case T_Driftfile:
 			if ('\0' == curr_var->value.s[0]) {
 				stats_drift_file = 0;
@@ -2649,6 +2649,7 @@ is_sane_resolved_address(
 	}
 
 	if (IS_IPV6(peeraddr) && !ipv6_works)
+		/* FIXME: error message */
 		return false;
 
 	/* Ok, all tests succeeded, now we can return true */
@@ -2779,10 +2780,10 @@ config_peers(
 				NULL,
 				curr_peer->host_mode,
 				&curr_peer->ctl);
-			/*
-			 * If we have a numeric address, we can safely
-			 * proceed in the mainline with it.
-			 */
+		/*
+		 * If we have a numeric address, we can safely
+		 * proceed in the mainline with it.
+		 */
 		} else if (is_ip_address(curr_peer->addr->address,
 					 curr_peer->addr->type, &peeraddr)) {
 
@@ -2853,12 +2854,14 @@ config_peers(
 			/* DNS lookup */
 		} else {
 			AF(&peeraddr) = curr_peer->addr->type;
-			peer_config(
+			struct peer *peer = peer_config(
 				&peeraddr,
 				curr_peer->addr->address,
 				NULL,
 				curr_peer->host_mode,
 				&curr_peer->ctl);
+			if (NULL == peer)
+				msyslog(LOG_INFO, "CONFIG: configpeers: Ignoring duplicate '%s'", curr_peer->addr->address);
 		}
 	}
 }
@@ -3041,7 +3044,8 @@ config_ntpd(
 	config_monitor(ptree);
 	config_auth(ptree);
 	config_tos(ptree);
-	config_access(ptree);
+	config_access(ptree);	/* before config_peers */
+	config_extra(ptree);
 	config_tinker(ptree);
 	config_nts(ptree);
 	config_rlimit(ptree);
@@ -3099,9 +3103,6 @@ getconfig(const char *explicit_config)
 	config_file = CONFIG_FILE;
 
 	if (explicit_config) {
-#ifdef HAVE_NETINFO_NI_H
-	    check_netinfo = false;
-#endif
 	    config_file = explicit_config;
 	}
 
@@ -3162,11 +3163,6 @@ void readconfig(const char *config_file)
 	}
 
 	if (srccount == 0) {
-#ifdef HAVE_NETINFO_NI_H
-		/* If there is no config_file, try NetInfo. */
-	    if (check_netinfo)
-		config_netinfo = get_netinfo_config();
-#endif /* HAVE_NETINFO_NI_H */
 	    io_open_sockets();
 	}
 
@@ -3178,11 +3174,6 @@ void readconfig(const char *config_file)
 	cfgt.timestamp = time(NULL);
 
 	save_and_apply_config_tree(true);
-
-#ifdef HAVE_NETINFO_NI_H
-	if (config_netinfo)
-		free_netinfo_config(config_netinfo);
-#endif /* HAVE_NETINFO_NI_H */
 }
 
 
@@ -3308,183 +3299,6 @@ get_logmask(
 	return 0;
 }
 
-
-#ifdef HAVE_NETINFO_NI_H
-
-/*
- * get_netinfo_config - find the nearest NetInfo domain with an ntp
- * configuration and initialize the configuration state.
- */
-static struct netinfo_config_state *
-get_netinfo_config(void)
-{
-	ni_status status;
-	void *domain;
-	ni_id config_dir;
-	struct netinfo_config_state *config;
-
-	if (ni_open(NULL, ".", &domain) != NI_OK) return NULL;
-
-	while ((status = ni_pathsearch(domain, &config_dir, NETINFO_CONFIG_DIR)) == NI_NODIR) {
-		void *next_domain;
-		if (ni_open(domain, "..", &next_domain) != NI_OK) {
-			ni_free(next_domain);
-			break;
-		}
-		ni_free(domain);
-		domain = next_domain;
-	}
-	if (status != NI_OK) {
-		ni_free(domain);
-		return NULL;
-	}
-
-	config = emalloc(sizeof(*config));
-	config->domain = domain;
-	config->config_dir = config_dir;
-	config->prop_index = 0;
-	config->val_index = 0;
-	config->val_list = NULL;
-
-	return config;
-}
-
-
-/*
- * free_netinfo_config - release NetInfo configuration state
- */
-static void
-free_netinfo_config(
-	struct netinfo_config_state *config
-	)
-{
-	ni_free(config->domain);
-	free(config);
-}
-
-
-/*
- * gettokens_netinfo - return tokens from NetInfo
- */
-static int
-gettokens_netinfo (
-	struct netinfo_config_state *config,
-	char **tokenlist,
-	int *ntokens
-	)
-{
-	int prop_index = config->prop_index;
-	int val_index = config->val_index;
-	char **val_list = config->val_list;
-
-	/*
-	 * Iterate through each keyword and look for a property that matches it.
-	 */
-  again:
-	if (!val_list) {
-		for (; prop_index < COUNTOF(keywords); prop_index++)
-		{
-			ni_namelist namelist;
-			struct keyword current_prop = keywords[prop_index];
-			ni_index index;
-
-			/*
-			 * For each value associated in the property, we're going to return
-			 * a separate line. We squirrel away the values in the config state
-			 * so the next time through, we don't need to do this lookup.
-			 */
-			NI_INIT(&namelist);
-			if (NI_OK == ni_lookupprop(config->domain,
-			    &config->config_dir, current_prop.text,
-			    &namelist)) {
-
-				/* Found the property, but it has no values */
-				if (namelist.ni_namelist_len == 0) continue;
-
-				config->val_list =
-				    eallocarray(
-					(namelist.ni_namelist_len + 1),
-					sizeof(char*));
-				val_list = config->val_list;
-
-				for (index = 0;
-				     index < namelist.ni_namelist_len;
-				     index++) {
-					char *value;
-
-					value = namelist.ni_namelist_val[index];
-					val_list[index] = estrdup(value);
-				}
-				val_list[index] = NULL;
-
-				break;
-			}
-			ni_namelist_free(&namelist);
-		}
-		config->prop_index = prop_index;
-	}
-
-	/* No list; we're done here. */
-	if (!val_list)
-		return CONFIG_UNKNOWN;
-
-	/*
-	 * We have a list of values for the current property.
-	 * Iterate through them and return each in order.
-	 */
-	if (val_list[val_index]) {
-		int ntok = 1;
-		int quoted = 0;
-		char *tokens = val_list[val_index];
-
-		msyslog(LOG_INFO, "CONFIG: %s %s", keywords[prop_index].text, val_list[val_index]);
-
-		(const char*)tokenlist[0] = keywords[prop_index].text;
-		for (ntok = 1; ntok < MAXTOKENS; ntok++) {
-			tokenlist[ntok] = tokens;
-			while (!ISEOL(*tokens) && (!ISSPACE(*tokens) || quoted))
-				quoted ^= (*tokens++ == '"');
-
-			if (ISEOL(*tokens)) {
-				*tokens = '\0';
-				break;
-			} else {		/* must be space */
-				*tokens++ = '\0';
-				while (ISSPACE(*tokens))
-					tokens++;
-				if (ISEOL(*tokens))
-					break;
-			}
-		}
-
-		if (ntok == MAXTOKENS) {
-			/* HMS: chomp it to lose the EOL? */
-			msyslog(LOG_ERR,
-				"CONFIG: gettokens_netinfo: too many tokens.  Ignoring: %s",
-				tokens);
-		} else {
-			*ntokens = ntok + 1;
-		}
-
-		config->val_index++;	/* HMS: Should this be in the 'else'? */
-
-		return keywords[prop_index].keytype;
-	}
-
-	/* We're done with the current property. */
-	prop_index = ++config->prop_index;
-
-	/* Free val_list and reset counters. */
-	for (val_index = 0; val_list[val_index]; val_index++)
-		free(val_list[val_index]);
-	free(val_list);
-	val_list = config->val_list = NULL;
-	val_index = config->val_index = 0;
-
-	goto again;
-}
-#endif /* HAVE_NETINFO_NI_H */
-
 /*
  * check my_node->addr for CIDR notation
  * if so, convert to old addr/mask notation and override mask
