@@ -1,8 +1,6 @@
 /*
  * ntp_leapsec.c - leap second processing for NTPD
  *
- * Written by Juergen Perlinger <perlinger@ntp.org> for the NTP project.
- *
  * ----------------------------------------------------------------------
  * This is an attempt to get the leap second handling into a dedicated
  * module to make the somewhat convoluted logic testable.
@@ -11,7 +9,8 @@
  * strtoull(3) is large enough to parse any integer literal found in these
  * files, and that C will promote such values to uint64_t properly.
  *
- * Copyright 2015 by the NTPsec project contributors
+ * Copyright Juergen Perlinger <perlinger@ntp.org>
+ * Copyright the NTPsec project contributors
  * SPDX-License-Identifier: NTP
  */
 
@@ -30,6 +29,7 @@
 #include "lib_strbuf.h"
 
 #include <openssl/evp.h>
+#include "hack-ancient-openssl.h"
 
 #define ISC_SHA1_DIGESTLENGTH 20U
 
@@ -83,12 +83,8 @@ static void   reset_times(leap_table_t*);
 static bool   leapsec_add(leap_table_t*, time_t, int);
 static bool   leapsec_raw(leap_table_t*, time_t, int, bool);
 
-/* time_t is unsigned.  This is used for infinity in tables */
-#if NTP_SIZEOF_TIME_T == 8
-# define LAST_time_t 0x7fffffffffffffff
-#elif NTP_SIZEOF_TIME_T == 4
-# define LAST_time_t 0x7fffffff
-#endif
+// time_t is unsigned.  This is used for infinity in tables
+#define LAST_time_t ((8 == sizeof(time_t))? 0x7fffffffffffffff : 0x7fffffff)
 
 /* =====================================================================
  * Get & Set the current leap table
@@ -944,7 +940,7 @@ leapsec_validate(
 	char           line[50];
 	int            hlseen = -1;
 
-	mdctx = EVP_MD_CTX_create();
+	mdctx = EVP_MD_CTX_new();
 	EVP_DigestInit_ex(mdctx, EVP_sha1(), NULL);
 	while (get_line(func, farg, line, sizeof(line))) {
 		if (!strncmp(line, "#h", 2)) {
@@ -958,7 +954,7 @@ leapsec_validate(
 		}
 	}
 	EVP_DigestFinal_ex(mdctx, ldig.hv, NULL);
-	EVP_MD_CTX_destroy(mdctx);
+	EVP_MD_CTX_free(mdctx);
 
 	if (0 > hlseen) {
 		return LSVALID_NOHASH;
