@@ -73,7 +73,7 @@
  * the first tv_Xsec longword is guaranteed to be zero, while the second is
  * significant (and should be in the allowable range).  In the padded 64+32
  * case, the first longword is the significant part (and should be in range),
- * while the second is possibly unintialized padding.  Hence, if the first
+ * while the second is possibly uninitialized padding.  Hence, if the first
  * longword is nonzero and in range, then it's clearly the significant part;
  * if the first longword is zero and the second is in range, either the
  * second part is the significant part, or the value is exactly zero while
@@ -99,7 +99,7 @@
  * functions defined here will be used in any given build, but we define
  * both to avoid additional conditionals that need to be kept in sync with
  * other parts of the code.  The void casts within the definitions suppress
- * the usual "unsed function" warnings, and the "unemitted inline" warning
+ * the usual "unused function" warnings, and the "unemitted inline" warning
  * from clang is disabled explicitly.
  */
 
@@ -337,7 +337,12 @@ fetch_packetstamp(
 	}
 #if defined(SO_TIMESTAMPNS)
 	/* Linux and ?? */
-	if (SCM_TIMESTAMPNS != cmsghdr->cmsg_type) {
+	if ((SCM_TIMESTAMPNS != cmsghdr->cmsg_type)
+#ifdef SO_TIMESTAMPNS_OLD
+	    /* Ubuntu 20.04.2 on ZeroPi, see #842 */
+            && (SO_TIMESTAMPNS_OLD != cmsghdr->cmsg_type)
+#endif
+          ) {
 #elif defined(SO_TS_CLOCK)
 	/* FreeBSD */
 	if (SCM_REALTIME != cmsghdr->cmsg_type) {
@@ -346,12 +351,28 @@ fetch_packetstamp(
 #else
 # error "Can't get packet timestamp"
 #endif
-		DPRINT(4,
-                        ("fetch_timestamp: strange control message 0x%x\n",
-			     (unsigned)cmsghdr->cmsg_type));
-		msyslog(LOG_ERR,
-			"ERR: fetch_timestamp: strange control message 0x%x",
-                             (unsigned)cmsghdr->cmsg_type);
+                char errbuf[128];
+
+                snprintf(errbuf, sizeof(errbuf),
+                        "fetch_timestamp: strange control message "
+                        "len x%x, level x%x type x%x\n",
+		       (unsigned)cmsghdr->cmsg_len,
+		       (unsigned)cmsghdr->cmsg_level,
+		       (unsigned)cmsghdr->cmsg_type);
+		DPRINT(4, ("%s", errbuf));
+		msyslog(LOG_ERR, "ERR: %s", errbuf);
+
+                // debug
+                snprintf(errbuf, sizeof(errbuf),
+                        "fetch_timestamp: sizeof(size_t) %lu, sizeof(int) %lu "
+                        "sizeof(cmsghdr) %lu\n",
+                        (unsigned long)sizeof(size_t),
+			(unsigned long)sizeof(int),
+			(unsigned long)sizeof(struct cmsghdr));
+		DPRINT(4, ("%s", errbuf));
+		msyslog(LOG_ERR, "ERR: %s", errbuf);
+                // debug
+
 		exit(2);
 		/* Could loop and skip strange types. */
 		/* cmsghdr = CMSG_NXTHDR(msghdr, cmsghdr); */
