@@ -109,7 +109,7 @@ static	unsigned short	restrict_source_mflags;
  */
 static restrict_u *	alloc_res4(void);
 static restrict_u *	alloc_res6(void);
-static void		free_res(restrict_u *, int);
+static void		free_res(restrict_u *, bool);
 static void		inc_res_limited(void);
 static void		dec_res_limited(void);
 static restrict_u *	match_restrict4_addr(uint32_t, unsigned short);
@@ -132,7 +132,7 @@ init_restrict(void)
 	 * sorted by descending address followed by descending mask:
 	 *
 	 *   address	  mask
-	 * 192.168.0.0	255.255.255.0	kod limited noquery nopeer
+	 * 192.168.0.0	255.255.255.0	kod limited noquery
 	 * 192.168.0.0	255.255.0.0	kod limited
 	 * 0.0.0.0	0.0.0.0		kod limited noquery
 	 *
@@ -154,8 +154,15 @@ init_restrict(void)
 	 * behavior as but reversed implementation compared to the docs.
 	 *
 	 */
+
 	LINK_SLIST(rstrct.restrictlist4, &restrict_def4, link);
 	LINK_SLIST(rstrct.restrictlist6, &restrict_def6, link);
+	restrict_def4.flags = RES_Default;
+	restrict_def6.flags = RES_Default;
+	if (RES_Default & RES_LIMITED) {
+		inc_res_limited();  /* IPv4 */
+		inc_res_limited();  /* IPv6 */
+	}
 	restrictcount = 2;
 }
 
@@ -213,7 +220,7 @@ alloc_res6(void)
 static void
 free_res(
 	restrict_u *	res,
-	int		v6
+	bool		v6
 	)
 {
 	restrict_u **	plisthead;
@@ -245,7 +252,7 @@ static void
 inc_res_limited(void)
 {
 	if (!res_limited_refcnt)
-		mon_start(MON_RES);
+		mon_setup(MON_RES);
 	res_limited_refcnt++;
 }
 
@@ -255,7 +262,7 @@ dec_res_limited(void)
 {
 	res_limited_refcnt--;
 	if (!res_limited_refcnt)
-		mon_stop(MON_RES);
+		mon_setdown(MON_RES);
 }
 
 
@@ -265,15 +272,11 @@ match_restrict4_addr(
 	unsigned short	port
 	)
 {
-	const int	v6 = 0;
 	restrict_u *	res;
 	restrict_u *	next;
 
 	for (res = rstrct.restrictlist4; res != NULL; res = next) {
 		next = res->link;
-		if (res->expire &&
-		    res->expire <= current_time)
-			free_res(res, v6);
 		if (res->u.v4.addr == (addr & res->u.v4.mask)
 		    && (!(RESM_NTPONLY & res->mflags)
 			|| NTP_PORT == port))
@@ -289,7 +292,6 @@ match_restrict6_addr(
 	unsigned short		port
 	)
 {
-	const int	v6 = 1;
 	restrict_u *	res;
 	restrict_u *	next;
 	struct in6_addr	masked;
@@ -297,9 +299,6 @@ match_restrict6_addr(
 	for (res = rstrct.restrictlist6; res != NULL; res = next) {
 		next = res->link;
 		INSIST(next != res);
-		if (res->expire &&
-		    res->expire <= current_time)
-			free_res(res, v6);
 		MASK_IPV6_ADDR(&masked, addr, &res->u.v6.mask);
 		if (ADDR6_EQ(&masked, &res->u.v6.addr)
 		    && (!(RESM_NTPONLY & res->mflags)
@@ -486,11 +485,10 @@ hack_restrict(
 	sockaddr_u *	resaddr,
 	sockaddr_u *	resmask,
 	unsigned short	mflags,
-	unsigned short	flags,
-	unsigned long	expire
+	unsigned short	flags
 	)
 {
-	int		v6;
+	bool		v6;
 	restrict_u	match;
 	restrict_u *	res;
 	restrict_u **	plisthead;
@@ -499,6 +497,7 @@ hack_restrict(
 		   op, socktoa(resaddr), socktoa(resmask), mflags, flags));
 
 	if (NULL == resaddr) {
+		/* restrict source */
 		REQUIRE(NULL == resmask);
 		REQUIRE(RESTRICT_FLAGS == op);
 		restrict_source_flags = flags;
@@ -510,10 +509,10 @@ hack_restrict(
 	ZERO(match);
 	/* silence VC9 potentially uninit warnings */
 	res = NULL;
-	v6 = 0;
+	v6 = false;
 
 	if (IS_IPV4(resaddr)) {
-		v6 = 0;
+		v6 = false;
 		/*
 		 * Get address and mask in host byte order for easy
 		 * comparison as uint32_t
@@ -523,7 +522,7 @@ hack_restrict(
 		match.u.v4.addr &= match.u.v4.mask;
 
 	} else if (IS_IPV6(resaddr)) {
-		v6 = 1;
+		v6 = true;
 		/*
 		 * Get address and mask in network byte order for easy
 		 * comparison as byte sequences (e.g. memcmp())
@@ -537,7 +536,6 @@ hack_restrict(
 
 	match.flags = flags;
 	match.mflags = mflags;
-	match.expire = expire;
 	res = match_restrict_entry(&match, v6);
 
 	switch (op) {
@@ -612,42 +610,36 @@ hack_restrict(
 }
 
 
-/*
- * restrict_source - maintains dynamic "restrict source ..." entries as
- *		     peers come and go.
+/* restrict_source - poke hole in restrictions if needed
+ *   requires "restrict source <flags|NULL>"
+ * Called in 3 cases:
+ *   newpeer when allocating a slot with IP Address
+ *   dns_check/dns_take_server when DNS assigns an IP Address
+ *   nts_check/dns_take_server when NTS assigns an IP Address
+ *
+ * Holes created have RESM_SOURCE in mflags
+ * Restrictions must be initialized before adding servers
  */
 void
 restrict_source(
-	sockaddr_u *	addr,
-	bool		farewell,	/* false to add, true to remove */
-	unsigned long	expire		/* 0 is infinite, valid until */
+	struct peer *	peer
 	)
 {
+	sockaddr_u *	addr = &peer->srcadr;
 	sockaddr_u	onesmask;
 	restrict_u *	res;
-	int		found_specific;
-
-	if (!restrict_source_enabled || SOCK_UNSPEC(addr) || IS_MCAST(addr))
-		return;
+	bool		found_specific = false;
+	bool		need_poke = false;
+	bool		auth, nts;
 
 	REQUIRE(AF_INET == AF(addr) || AF_INET6 == AF(addr));
 
 	SET_HOSTMASK(&onesmask, AF(addr));
-	if (farewell) {
-		hack_restrict(RESTRICT_REMOVE, addr, &onesmask,
-			      0, 0, 0);
-		DPRINT(1, ("restrict_source: %s removed", socktoa(addr)));
-		return;
-	}
 
 	/*
 	 * If there is a specific entry for this address, hands
 	 * off, as it is condidered more specific than "restrict
 	 * server ...".
-	 * However, if the specific entry found is a fleeting one
-	 * added by pool_xmit() before soliciting, replace it
-	 * immediately regardless of the expire value to make way
-	 * for the more persistent entry.
 	 */
 	if (IS_IPV4(addr)) {
 		res = match_restrict4_addr(SRCADR(addr), SRCPORT(addr));
@@ -658,17 +650,65 @@ restrict_source(
 		found_specific = ADDR6_EQ(&res->u.v6.mask,
 					  &SOCK_ADDR6(&onesmask));
 	}
-	if (!expire && found_specific && res->expire) {
-		found_specific = 0;
-		free_res(res, IS_IPV6(addr));
+
+	if (RES_IGNORE & res->flags) {
+		need_poke = true;
+	}
+	auth = (0 != peer->cfg.peerkey);
+	nts = peer->cfg.flags & FLAG_NTS;
+	if (RES_NOTRUST & res->flags && !auth && !nts) {
+		/* needs authentication, but this slot doesn't have any */
+		need_poke = true;
+	}
+	if (!need_poke) {
+		/* works without a hole */
+		return;
 	}
 	if (found_specific) {
+		msyslog(LOG_ERR, "RESTRICT: Specific restriction will break %s",
+			socktoa(addr));
+		return;
+	}
+	if (!restrict_source_enabled) {
+		msyslog(LOG_ERR, "RESTRICT: Can't poke hole in restrictions for %s - need \"restrict source <flags>\"",
+			socktoa(addr));
 		return;
 	}
 
+	msyslog(LOG_INFO, "RESTRICT: Poking hole in restrictions for %s",
+		socktoa(addr));
+
 	hack_restrict(RESTRICT_FLAGS, addr, &onesmask,
-		      restrict_source_mflags, restrict_source_flags,
-		      expire);
-	DPRINT(1, ("restrict_source: %s host restriction added\n",
-		   socktoa(addr)));
+		      restrict_source_mflags, restrict_source_flags);
 }
+
+/* unrestrict_source - remove hole poked in restrictions
+ */
+void
+unrestrict_source(
+	struct peer *	peer
+	)
+{
+	sockaddr_u *	addr = &peer->srcadr;
+	sockaddr_u	onesmask;
+	restrict_u *	res;
+
+	if (IS_IPV4(addr)) {
+		res = match_restrict4_addr(SRCADR(addr), SRCPORT(addr));
+	} else {
+		res = match_restrict6_addr(&SOCK_ADDR6(addr),
+					   SRCPORT(addr));
+	}
+	if (!(res->mflags & RESM_SOURCE)) {
+		return;		/* nothing to cleanup */
+	}
+
+	msyslog(LOG_INFO, "RESTRICT: Removing hole in restrictions for %s",
+		socktoa(addr));
+
+	SET_HOSTMASK(&onesmask, AF(addr));
+	hack_restrict(RESTRICT_REMOVE, addr, &onesmask, 0, 0);
+
+}
+
+
