@@ -10,10 +10,10 @@
 #include "ntp_filegen.h"
 #include "ntp_leapsec.h"
 #include "ntp_stdlib.h"
-#include "ntp_stdlib.h"
 #include "ntp_auth.h"
 #include "ntpd.h"
 #include "timespecops.h"
+#include "nts.h"
 
 #include <stdio.h>
 #include <libgen.h>
@@ -61,8 +61,11 @@ static FILEGEN loopstats;
 static FILEGEN peerstats;
 static FILEGEN protostats;
 static FILEGEN rawstats;
+static FILEGEN refstats;
 static FILEGEN sysstats;
 static FILEGEN usestats;
+static FILEGEN ntsstats;
+static FILEGEN ntskestats;
 
 /*
  * This controls whether stats are written to the fileset. Provided
@@ -80,6 +83,8 @@ static double prev_drift_comp;		/* last frequency update */
  */
 static	void	record_sys_stats(void);
 static	void	record_use_stats(void);
+static	void	record_nts_stats(void);
+static	void	record_ntske_stats(void);
 	void	ntpd_time_stepped(void);
 static  void	check_leap_expiration(bool, time_t);
 
@@ -108,10 +113,13 @@ uninit_util(void)
 	filegen_unregister("clockstats");
 	filegen_unregister("loopstats");
 	filegen_unregister("rawstats");
+	filegen_unregister("refstats");
 	filegen_unregister("sysstats");
 	filegen_unregister("peerstats");
 	filegen_unregister("protostats");
 	filegen_unregister("usestats");
+	filegen_unregister("ntsstats");
+	filegen_unregister("ntpkestats");
 }
 #endif /* DEBUG */
 
@@ -125,10 +133,13 @@ init_util(void)
 	filegen_register(statsdir, "clockstats",  &clockstats);
 	filegen_register(statsdir, "loopstats",	  &loopstats);
 	filegen_register(statsdir, "rawstats",	  &rawstats);
+	filegen_register(statsdir, "refstats",	  &refstats);
 	filegen_register(statsdir, "sysstats",	  &sysstats);
 	filegen_register(statsdir, "peerstats",	  &peerstats);
 	filegen_register(statsdir, "protostats",  &protostats);
 	filegen_register(statsdir, "usestats",	  &usestats);
+	filegen_register(statsdir, "ntsstats",	  &ntsstats);
+	filegen_register(statsdir, "ntskestats",  &ntskestats);
 
 	/*
 	 * register with libntp ntp_set_tod() to call us back
@@ -140,6 +151,24 @@ init_util(void)
 #endif /* DEBUG */
 }
 
+/*
+ * write_pidfile - write the PID file
+ */
+void
+write_pidfile(
+	const char *pidfile,
+	pid_t pid)
+{
+	FILE	*fp;
+
+	if ((fp = fopen(pidfile, "w")) == NULL) {
+		msyslog(LOG_ERR, "LOG: pid file %s: %s",
+		    pidfile, strerror(errno));
+		return;
+	}
+	fprintf(fp, "%ld", (long)pid);
+	fclose(fp);
+}
 
 /*
  * drift_write - write drift to file, speeds up restart
@@ -155,6 +184,8 @@ init_util(void)
 static void drift_write(char *driftfile, double drift) {
 	FILE *new;
 	char tempfile[PATH_MAX];
+	if (loop_data.lockclock)
+	    return;	/* Don't trash drift file -- we aren't maintaining it */
 	strlcpy(tempfile, driftfile, sizeof(tempfile));
 	strlcat(tempfile, "-tmp", sizeof(tempfile));
 	if ((new = fopen(tempfile, "w")) == NULL) {
@@ -178,7 +209,9 @@ void
 write_stats(void) {
 	record_sys_stats();
 	record_use_stats();
-	if (stats_drift_file != 0) {
+	record_nts_stats();
+	record_ntske_stats();
+	if (stats_drift_file != NULL) {
 
 		/*
 		 * When the frequency file is written, initialize the
@@ -229,7 +262,6 @@ stats_config(
 	const char *invalue	/* only one type so far */
 	)
 {
-	FILE	*fp;
 	const char *value;
 	size_t	len;
 	double	new_drift = 0;
@@ -296,13 +328,7 @@ stats_config(
 	 * Open pid file.
 	 */
 	case STATS_PID_FILE:
-		if ((fp = fopen(value, "w")) == NULL) {
-			msyslog(LOG_ERR, "LOG: pid file %s: %s",
-			    value, strerror(errno));
-			break;
-		}
-		fprintf(fp, "%d", (int)getpid());
-		fclose(fp);
+		write_pidfile(value, getpid());
 		break;
 
 	/*
@@ -516,46 +542,104 @@ mprintf_clock_stats(
  * source IP address (old format) or drivername(unit) (new format)
  * destination peer address
  * t1 t2 t3 t4 timestamps
- * various other local statistics
+ * various other chunks of the packet
  */
 void
 record_raw_stats(
-	struct peer *peer,
-	int	leap,
-	int	version,
-	int	mode,
-	int	stratum,
-	int	ppoll,
-	int	precision,
-	double	root_delay,	/* seconds */
-	double	root_dispersion,/* seconds */
-	refid_t	refid,
-	unsigned int	outcount
-	)
+  struct peer *peer,
+  struct recvbuf *rbufp,
+  unsigned int flag,
+  unsigned int outcount)
 {
 	struct timespec	now;
 	const sockaddr_u *dstaddr = peer->dstadr ? &peer->dstadr->sin : NULL;
+	/* This lies.  It shows the time we sent it rather than the
+	 * data from the packet which was probably random.
+	 * See data minimization in peer_xmit()
+	 * That's what code processing rawstats expects.
+	 */
 	l_fp	t1 = peer->org_ts;	/* originate timestamp */
-	l_fp	t2 = peer->rec;		/* receive timestamp */
-	l_fp	t3 = peer->xmt;		/* transmit timestamp */
-	l_fp	t4 = peer->dst;		/* destination timestamp */
+	l_fp	t2 = rbufp->pkt.rec;	/* receive timestamp */
+	l_fp	t3 = rbufp->pkt.xmt;	/* transmit timestamp */
+	l_fp	t4 = rbufp->recv_time;	/* destination timestamp */
+	int	stratum;
+	refid_t refid = *(const uint32_t*)rbufp->pkt.refid;
+	double rootdelay, rootdisp;
 
 	if (!stats_control)
 		return;
 
 	clock_gettime(CLOCK_REALTIME, &now);
 	filegen_setup(&rawstats, now.tv_sec);
-	if (rawstats.fp != NULL) {
-		fprintf(rawstats.fp, "%s %s %s %s %s %s %s %d %d %d %d %d %d %.6f %.6f %s %u\n",
-		    timespec_to_MJDtime(&now),
-		    peerlabel(peer), dstaddr ?  socktoa(dstaddr) : "-",
-		    ulfptoa(t1, 9), ulfptoa(t2, 9),
-		    ulfptoa(t3, 9), ulfptoa(t4, 9),
-		    leap, version, mode, stratum, ppoll, precision,
-		    root_delay, root_dispersion, refid_str(refid, stratum),
-		    outcount);
-		fflush(rawstats.fp);
-	}
+	if (rawstats.fp == NULL) return;
+
+	/* copy of PKT_TO_STRATUM from ntp_proto.c */
+	stratum = rbufp->pkt.stratum;
+	if (stratum == STRATUM_PKT_UNSPEC) stratum = STRATUM_UNSPEC;
+
+	rootdelay = scalbn((double)rbufp->pkt.rootdelay, -16);
+	rootdisp = scalbn((double)rbufp->pkt.rootdisp, -16);
+
+	fprintf(rawstats.fp, "%s %s %s %s %s %s %s %d %d %d %d %d %d %.6f %.6f %s %u %u %x\n",
+	    timespec_to_MJDtime(&now),
+	    peerlabel(peer), dstaddr ?  socktoa(dstaddr) : "-",
+	    ulfptoa(t1, 9), ulfptoa(t2, 9),
+	    ulfptoa(t3, 9), ulfptoa(t4, 9),
+	    PKT_LEAP(rbufp->pkt.li_vn_mode),
+	    PKT_VERSION(rbufp->pkt.li_vn_mode),
+	    PKT_MODE(rbufp->pkt.li_vn_mode),
+	    stratum,
+	    rbufp->pkt.ppoll,
+	    rbufp->pkt.precision,
+	    rootdelay,
+	    rootdisp,
+	    refid_str(refid, stratum),
+	    outcount, peer->bogons, flag);
+	fflush(rawstats.fp);
+}
+
+/*
+ * record_ref_stats - write refclock timestamps to file
+ *
+ * file format
+ * day (MJD)
+ * time (s past midnight)
+ * peer IP address
+ * i, j, n from refclock_sample
+ * t1 t2 t3 t4 t5, timestamps
+ * jitter, std_dev, std_dev_all
+ */
+
+void record_ref_stats(
+    const struct peer *peer,
+    int     n,              /* Number of samples */
+    int     i,              /* Index of first sample used */
+    int     j,              /* Index of last sample used */
+    double  t1,             /* Value of first sample */
+    double  t2,             /* Value of first sample used */
+    double  t3,             /* answer/median */
+    double  t4,             /* Value of last sample used */
+    double  t5,             /* Value of last sample */
+    double  jitter,
+    double  std_dev,        /* std deviation of trimmed subset */
+    double  std_dev_all     /* std deviation of everything */
+    )
+{
+    struct timespec now;
+
+    if (!stats_control)
+        return;
+
+    clock_gettime(CLOCK_REALTIME, &now);
+    filegen_setup(&refstats, now.tv_sec);
+    if (refstats.fp != NULL) {
+        fprintf(refstats.fp,
+            "%s %s %d %d %d  %.9f %.9f %.9f %.9f %.9f  %.9f %.9f %.9f\n",
+            timespec_to_MJDtime(&now), peerlabel(peer),
+            n, i, j,
+            t1, t2, t3, t4, t5, jitter, std_dev, std_dev_all);
+        fflush(refstats.fp);
+    }
 }
 
 
@@ -576,6 +660,7 @@ record_raw_stats(
  * declined
  * rate exceeded
  * KoD sent
+ * NTPv1 packets
  */
 void
 record_sys_stats(void)
@@ -590,15 +675,16 @@ record_sys_stats(void)
 	if (sysstats.fp != NULL) {
 		fprintf(sysstats.fp,
 		    "%s %u %" PRIu64 " %" PRIu64 " %" PRIu64 " %" PRIu64 " %" PRIu64
-		    " %" PRIu64 " %" PRIu64 " %" PRIu64 " %" PRIu64 " %" PRIu64 "\n",
-			timespec_to_MJDtime(&now), current_time - stat_stattime(),
+		    " %" PRIu64 " %" PRIu64 " %" PRIu64 " %" PRIu64 \
+		    " %" PRIu64 " %" PRIu64"\n",
+			timespec_to_MJDtime(&now), stat_stattime(),
 			stat_received(), stat_processed(), stat_newversion(),
 			stat_oldversion(), stat_restricted(), stat_badlength(),
 			stat_badauth(), stat_declined(), stat_limitrejected(),
-			stat_kodsent());
+			stat_kodsent(), stat_version1());
 		fflush(sysstats.fp);
-		proto_clr_stats();
 	}
+	proto_clr_stats();
 }
 
 
@@ -624,17 +710,17 @@ void record_use_stats(void)
 	clock_gettime(CLOCK_REALTIME, &now);
 	filegen_setup(&usestats, now.tv_sec);
 	if (usestats.fp != NULL) {
-		double utime, stimex;
+		double utime, stimex; /* stime() is in time.h */
 		getrusage(RUSAGE_SELF, &usage);
-		utime =  usage.ru_utime.tv_usec - oldusage.ru_utime.tv_usec;
+		utime = usage.ru_utime.tv_usec - oldusage.ru_utime.tv_usec;
 		utime /= 1E6;
-		utime += usage.ru_utime.tv_sec -  oldusage.ru_utime.tv_sec;
-		stimex =  usage.ru_stime.tv_usec - oldusage.ru_stime.tv_usec;
+		utime += usage.ru_utime.tv_sec - oldusage.ru_utime.tv_sec;
+		stimex = usage.ru_stime.tv_usec - oldusage.ru_stime.tv_usec;
 		stimex /= 1E6;
-		stimex += usage.ru_stime.tv_sec -  oldusage.ru_stime.tv_sec;
+		stimex += usage.ru_stime.tv_sec - oldusage.ru_stime.tv_sec;
 		fprintf(usestats.fp,
 		    "%s %u %.3f %.3f %ld %ld %ld %ld %ld %ld %ld %ld %ld\n",
-		    timespec_to_MJDtime(&now), current_time - stat_use_stattime(),
+		    timespec_to_MJDtime(&now), stat_use_stattime(),
 		    utime, stimex,
 		    usage.ru_minflt -   oldusage.ru_minflt,
 		    usage.ru_majflt -   oldusage.ru_majflt,
@@ -651,6 +737,76 @@ void record_use_stats(void)
 	}
 }
 
+#define nts_since(CNT) ((unsigned long long)(nts_cnt.CNT - old_nts_cnt.CNT))
+uptime_t nts_stattime;
+void record_nts_stats(void) {
+#ifndef DISABLE_NTS
+	struct timespec	now;
+
+	if (!stats_control)
+		return;
+
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&ntsstats, now.tv_sec);
+	if (ntsstats.fp != NULL) {
+		fprintf(ntsstats.fp,
+		    "%s %u %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu\n",
+		    timespec_to_MJDtime(&now), current_time-nts_stattime,
+		    nts_since(client_send),
+		    nts_since(client_recv_good),
+		    nts_since(client_recv_bad),
+		    nts_since(server_send),
+		    nts_since(server_recv_good),
+		    nts_since(server_recv_bad),
+		    nts_since(cookie_make),
+		    nts_since(cookie_not_server),
+		    nts_since(cookie_decode_total),
+		    nts_since(cookie_decode_current),
+		    nts_since(cookie_decode_old),
+		    nts_since(cookie_decode_old2),
+		    nts_since(cookie_decode_older),
+		    nts_since(cookie_decode_too_old),
+		    nts_since(cookie_decode_error) );
+		fflush(ntsstats.fp);
+	}
+	old_nts_cnt = nts_cnt;
+	nts_stattime = current_time;
+#endif
+}
+
+#define ntske_since(CNT) ((unsigned long long)(ntske_cnt.CNT - old_ntske_cnt.CNT))
+#define ntske_since_f(CNT) ((double)lfptod(ntske_cnt.CNT - old_ntske_cnt.CNT))
+uptime_t ntske_stattime;
+void record_ntske_stats(void) {
+#ifndef DISABLE_NTS
+	struct timespec	now;
+
+	if (!stats_control)
+		return;
+
+	clock_gettime(CLOCK_REALTIME, &now);
+	filegen_setup(&ntskestats, now.tv_sec);
+	if (ntsstats.fp != NULL) {
+		fprintf(ntskestats.fp,
+		    "%s %u %llu %.3f %.3f %llu %.3f %.3f %llu %.3f %.3f %llu %llu\n",
+		    timespec_to_MJDtime(&now), current_time-ntske_stattime,
+		    ntske_since(serves_good),
+		    ntske_since_f(serves_good_wall),
+		    ntske_since_f(serves_good_cpu),
+		    ntske_since(serves_nossl),
+		    ntske_since_f(serves_nossl_wall),
+		    ntske_since_f(serves_nossl_cpu),
+		    ntske_since(serves_bad),
+		    ntske_since_f(serves_bad_wall),
+		    ntske_since_f(serves_bad_cpu),
+		    ntske_since(probes_good),
+		    ntske_since(probes_bad) );
+		fflush(ntskestats.fp);
+	}
+	old_ntske_cnt = ntske_cnt;
+	ntske_stattime = current_time;
+#endif
+}
 
 /*
  * record_proto_stats - write system statistics to file
@@ -773,15 +929,19 @@ getauthkeys(
  */
 void
 ntpd_time_stepped(void) {
-	unsigned int saved_mon_enabled;
 
 	/*
 	 * flush the monitor MRU list which contains l_fp timestamps
 	 * which should not be compared across the step.
+	 *
+	 * This is evil if you are using the MRU list to get a summary
+	 * of all your traffic.  But time-steps don't happen often on
+	 * servers with enough traffic to be interesting.
+	 *
+	 * If we get to logging MRU slots, we should log everything here.
 	 */
 	if (MON_OFF != mon_data.mon_enabled) {
-		saved_mon_enabled = mon_data.mon_enabled;
-		mon_stop(MON_OFF);
-		mon_start((int)saved_mon_enabled);
+		mon_stop();
+		mon_start();
 	}
 }
