@@ -1,10 +1,10 @@
 /*
  * nts.c - Network Time Security (NTS) support
- * Copyright 2019 by the NTPsec project contributors
- * SPDX-License-Identifier: BSD-4-Clause-UC
+ * Copyright the NTPsec project contributors
+ * SPDX-License-Identifier: BSD-2-Clause
  *
  * Section references are to
- * https://tools.ietf.org/html/draft-ietf-ntp-using-nts-for-ntp-15
+ * https://tools.ietf.org/html/rfc8915
  *
  * This module exposes mostly functions and structure pointers (not
  * structures) so that the NTS implementation can be sealed off from
@@ -29,23 +29,29 @@
 #include "nts.h"
 #include "nts2.h"
 
+struct nts_counters nts_cnt, old_nts_cnt;
+struct ntske_counters ntske_cnt, old_ntske_cnt;
+
 struct ntsconfig_t ntsconfig = {
 	.ntsenable = false,
 	.mintls = NULL,
 	.maxtls = NULL,
-	.tlsciphers = NULL,
 	.tlsciphersuites = NULL,
+	.tlsecdhcurves = NULL,
 	.cert = NULL,
 	.key = NULL,
 	.KI = NULL,
 	.ca = NULL,
-	.aead = NULL
+	.aead = NULL,
+	.tlscipherserverpreference = false,
 };
 
 void nts_log_version(void);
 
 /*****************************************************/
 
+/* More SSL initialization in ssl_init() from libntp/ssl_init.c */
+
 void nts_init(void) {
 	bool ok = true;
 	nts_log_version();
@@ -73,27 +79,21 @@ void nts_init2(void) {
 	}
 }
 
-/* There are 3 cases:
- *  1: old, log build version
- *  2: new, match, log version
- *  3: new, mismatch, log both build and run
+/* There are 2 cases:
+ *  1: match, log version
+ *  2: mismatch, log both build and run
  */
 void nts_log_version(void) {
 	unsigned long buildVersion = OPENSSL_VERSION_NUMBER;
-#if (OPENSSL_VERSION_NUMBER < 0x10100000L)
-	/* Case 1 */
-	msyslog(LOG_INFO, "INIT: %s, %lx",
-		OPENSSL_VERSION_TEXT, buildVersion);
-#else
 	const char * text = OpenSSL_version(OPENSSL_VERSION);
 	bool match = (buildVersion == OpenSSL_version_num()) &&
 		(0 == strcmp(OPENSSL_VERSION_TEXT, text));
 	if (match) {
-		/* Case 2 */
+		/* Case 1 */
 		msyslog(LOG_INFO, "INIT: %s, %lx",
 			OPENSSL_VERSION_TEXT, buildVersion);
 	} else {
-                /* Case 3 */
+                /* Case 2 */
 		msyslog(LOG_INFO, "INIT: Built with %s, %lx",
 			OPENSSL_VERSION_TEXT, buildVersion);
 		msyslog(LOG_INFO, "INIT: Running with %s, %lx",
@@ -104,7 +104,21 @@ void nts_log_version(void) {
 			exit(1);
 		}
 	}
-#endif
+	/*
+	 * If the runtime OpenSSL is 1.1.1a, then bail, since we'll run into errors with the
+	 * TLSv1.3 maximum label length
+	 */
+	if (OpenSSL_version_num() == 0x1010101fL) {
+		msyslog(LOG_ERR, "INIT: OpenSSL 1.1.1a has a maximum label length bug, bailing");
+		exit(1);
+	}
+}
+
+/*****************************************************/
+
+void nts_timer(void) {
+	nts_cert_timer();
+	nts_cookie_timer();
 }
 
 /*****************************************************/
@@ -114,17 +128,10 @@ int nts_translate_version(const char *arg) {
 	if (NULL == arg) {
 		return 0;
 	}
-	if (0 == strcmp(arg, "TLS1.2"))
-		return TLS1_2_VERSION;
 	if (0 == strcmp(arg, "TLS1.3")) {
-#ifdef TLS1_3_VERSION
 		return TLS1_3_VERSION;
-#else
-		msyslog(LOG_ERR, "NTS: TLS1.3 not supported by this version of OpenSSL.");
-		return -1;
-#endif
 	}
-	msyslog(LOG_ERR, "NTS: unrecognized version string: %s.", arg);
+	msyslog(LOG_ERR, "NTS: TLS unrecognized version string: %s.", arg);
 	return -1;
 }
 
@@ -165,25 +172,9 @@ bool nts_load_versions(SSL_CTX *ctx) {
 	maxver = nts_translate_version(ntsconfig.maxtls);
 	if ((-1 == minver) || (-1 == maxver))
 		return false;
-#if (OPENSSL_VERSION_NUMBER == 0x1010101fL)
-	if (0 == maxver) {
-		msyslog(LOG_INFO, "NTS: Using TLS1.2 to avoid bug in OpenSSL 1.1.1a.");
-		maxver = TLS1_2_VERSION;
-	}
-#endif
-#if (OPENSSL_VERSION_NUMBER > 0x1010000fL)
-	if(0 == minver) minver = TLS1_2_VERSION;   // 3.
+	if(0 == minver) minver = TLS1_3_VERSION;   // 3.
 	SSL_CTX_set_min_proto_version(ctx, minver);
 	SSL_CTX_set_max_proto_version(ctx, maxver);
-#else
-	/* TLS 1.2 was added in 1.0.1, 14 Mar 2012
-	 * HGM hasn't seen anything older.  2019-Oct-26
-	 * versions older than 1.1.0  don't support min/max version requests.
-	 * That's OK, since we don't want anything older than 1.2 and
-	 * they don't support anything newer. */
-#define NO_OLD_VERSIONS SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1
-	SSL_CTX_set_options(ctx, NO_OLD_VERSIONS);
-#endif
 	return true;
 }
 
@@ -192,27 +183,45 @@ bool nts_load_ciphers(SSL_CTX *ctx) {
 	 * There is no SSL_CTX_get_cipher_list, so we can't easily read back
 	 * the ciphers to see what it took.
 	 * We could make a dummy SSL, read the list, then free it.
+	 * man SSL_CTX_set_ciphersuites() has info.
 	 */
-	if (NULL != ntsconfig.tlsciphers) {
-		if (1 != SSL_CTX_set_cipher_list(ctx, ntsconfig.tlsciphers)) {
-			msyslog(LOG_ERR, "NTS: troubles setting ciphers.");
+	if (NULL == ntsconfig.tlsciphersuites) {
+		return true;
+	}
+	/*  This used to set server-preference See #797 */
+	if (1 != SSL_CTX_set_ciphersuites(ctx, ntsconfig.tlsciphersuites)) {
+		msyslog(LOG_ERR, "NTS: troubles setting ciphersuites.");
+		return false;
+	} else {
+		msyslog(LOG_INFO, "NTS: set ciphersuites %s.", ntsconfig.tlsciphersuites);
+	}
+	return true;
+}
+
+bool nts_load_ecdhcurves(SSL_CTX *ctx) {
+	/* SSL_CTX_set1_groups_list ignores typos or curves it doesn't support.
+	 * There is no SSL_CTX_get_groups_list, so we can't easily read back
+	 * the ecdhcurves to see what it took.
+	 * We could make a dummy SSL, read the list, then free it.
+	 */
+	if (NULL != ntsconfig.tlsecdhcurves) {
+		/* FIXME -- const bug in OpenSSL */
+		char *copy = estrdup(ntsconfig.tlsecdhcurves);
+		if (1 != SSL_CTX_set1_groups_list(ctx, copy)) {
+			msyslog(LOG_ERR, "NTS: troubles setting ecdhcurves.");
+			free(copy);
 			return false;
 		} else {
-			msyslog(LOG_INFO, "NTS: set ciphers.");
+			msyslog(LOG_INFO, "NTS: set ecdhcurves %s.", ntsconfig.tlsecdhcurves);
 		}
+		free(copy);
 	}
-	if (NULL != ntsconfig.tlsciphersuites) {
-#ifdef TLS1_3_VERSION
-		if (1 != SSL_CTX_set_ciphersuites(ctx, ntsconfig.tlsciphersuites)) {
-			msyslog(LOG_ERR, "NTS: troubles setting ciphersuites.");
-			return false;
-		} else {
-			msyslog(LOG_INFO, "NTS: set ciphersuites.");
-		}
-#else
-		msyslog(LOG_ERR, "NTS: ciphersuites not supported on this version of OpenSSL.");
-#endif
-	}
+	return true;
+}
+
+bool nts_set_cipher_order(SSL_CTX *ctx) {
+	if (ntsconfig.tlscipherserverpreference)
+		SSL_CTX_set_options(ctx, SSL_OP_CIPHER_SERVER_PREFERENCE);
 	return true;
 }
 
@@ -307,6 +316,7 @@ int nts_ssl_write(SSL *ssl, uint8_t *buff, int buff_length) {
 	return bytes_written;
 }
 
+/* Each thread has it's own queue of errors */
 void nts_log_ssl_error(void) {
 	char buff[256];
 	int err = ERR_get_error();
@@ -322,10 +332,6 @@ void nts_log_ssl_error(void) {
 
 /* NB: KE length is body length, Extension length includes header. */
 
-/* 2 byte type, 2 byte length */
-#define NTS_KE_HDR_LNG 4
-#define NTS_KE_U16_LNG 2
-
 /* Troubles with signed/unsigned compares when using sizeof() */
 
 void ke_append_record_null(BufCtl* buf, uint16_t type) {
