@@ -105,6 +105,7 @@ bool nts_server_init(void) {
 	ok &= nts_load_versions(server_ctx);
 	ok &= nts_load_ciphers(server_ctx);
 	ok &= nts_load_ecdhcurves(server_ctx);
+	ok &= nts_set_cipher_order(server_ctx);
 
 	if (!ok) {
 		msyslog(LOG_ERR, "NTSs: Disabling NTS-KE server");
@@ -380,10 +381,10 @@ bool nts_ke_request(SSL *ssl) {
 	 * Our cookies can be 104, 136, or 168 for AES_SIV_CMAC_xxx
 	 * 8*168 fits comfortably into 2K.
 	 */
-	uint8_t buff[2048];
-	uint8_t c2s[NTS_MAX_KEYLEN], s2c[NTS_MAX_KEYLEN];
-	int aead, keylen;
-	struct BufCtl_t buf;
+	uint8_t buff[2048] = {0};
+	uint8_t c2s[NTS_MAX_KEYLEN] = {0}, s2c[NTS_MAX_KEYLEN] = {0};
+	int aead = NO_AEAD, keylen;
+	struct BufCtl_t buf = {0, 0};
 	int bytes_read, bytes_written;
 	int used;
 
@@ -393,7 +394,6 @@ bool nts_ke_request(SSL *ssl) {
 
 	buf.next = buff;
 	buf.left = bytes_read;
-	aead = NO_AEAD;
 	if (!nts_ke_process_receive(&buf, &aead))
 		return false;
 
@@ -539,20 +539,29 @@ bool nts_ke_process_receive(struct BufCtl_t *buf, int *aead) {
 			msyslog(LOG_INFO, "NTSs: Record: T=%d, L=%d, C=%d", type, length, critical);
 		switch (type) {
 		    case nts_error:
-			data = next_uint16(buf);
-			if (sizeof(data) != length)
+			if (sizeof(data) != length) {
 				msyslog(LOG_ERR, "NTSs: wrong length on error: %d", length);
+				return false;
+			}
+			data = next_uint16(buf);
 			msyslog(LOG_ERR, "NTSs: error: %d", data);
 			return false;
 		    case nts_next_protocol_negotiation:
+			if (sizeof(data) != length) {
+				msyslog(LOG_ERR, "NTSs: NPN-Wrong length: %d", length);
+				return false;
+			}
 			data = next_uint16(buf);
-			if ((sizeof(data) != length) || (data != nts_protocol_NTP)) {
-				msyslog(LOG_ERR, "NTSs: NPN-Wrong length or bad data: %d, %d",
-					length, data);
+			if (data != nts_protocol_NTP) {
+				msyslog(LOG_ERR, "NTSs: NPN-Bad data: %d", data);
 				return false;
 			}
 			break;
 		    case nts_algorithm_negotiation:
+			if (buf->left < length || length % sizeof(uint16_t) > 0) {
+				msyslog(LOG_ERR, "NTSs: AN-Wrong length: %d", length);
+				return false;
+			}
 			for (int i=0; i<length; i+=sizeof(uint16_t)) {
 				data = next_uint16(buf);
 				if (0 == nts_get_key_length(data)) {
@@ -604,6 +613,10 @@ bool nts_ke_setup_send(struct BufCtl_t *buf, int aead,
 	/* 4.1.5 AEAD Algorithm List */
 	ke_append_record_uint16(buf, nts_algorithm_negotiation, aead);
 
+	if (extra_port)
+	        ke_append_record_uint16(buf, nts_port_negotiation, extra_port);
+
+
 	for (int i=0; i<NTS_MAX_COOKIES; i++) {
 		uint8_t cookie[NTS_MAX_COOKIELEN];
 		int cookielen = nts_make_cookie(cookie, aead, c2s, s2c, keylen);
