@@ -44,9 +44,14 @@
  * oscillator. In extreme cases, this can cause clients to exceed the
  * 128-ms slew window and drop off the NTP subnet.
  *
+ * In lockclock mode, ntpd will not call ntp_adjtime() since that
+ * might trample on whatever some other program is trying to do.
+ * NB: setting loop_data.lockclock here is too late.
+ *    There is hack code in ntp_config.c to set it when parsing ntp.conf
+ *
  * Fudge Factors
+ *   flag1 set to 1 enables lockclock mode
  *
- * None currently supported.
  */
 /*
  * Local interface definitions
@@ -109,6 +114,9 @@ local_start(
 	memcpy(&pp->refid, "LOCL", REFIDLEN);
 	peer->sstclktype = CTL_SST_TS_LOCAL;
 	poll_time = current_time;
+	/* This is too late.  See comment way above. */
+	if (pp->sloppyclockflag & CLK_FLAG1)
+	    loop_data.lockclock = true;
 	return true;
 }
 
@@ -116,7 +124,7 @@ local_start(
 /*
  * local_poll - called by the transmit procedure
  *
- * ENABLE_LOCKCLOCK: If the kernel supports the nanokernel or microkernel
+ * If lockclock is on: If the kernel supports the nanokernel or microkernel
  * system calls, the leap bits are extracted from the kernel. If there
  * is a kernel error or the kernel leap bits are set to 11, the NTP leap
  * bits are set to 11 and the stratum is set to infinity. Otherwise, the
@@ -156,36 +164,52 @@ local_poll(
 	 * If another process is disciplining the system clock, we set
 	 * the leap bits and quality indicators from the kernel.
 	 */
-#if defined(ENABLE_LOCKCLOCK)
-	struct timex ntv;
-	memset(&ntv,  0, sizeof ntv);
-	switch (ntp_adjtime(&ntv)) {
-	case TIME_OK:
+	if (loop_data.lockclock) {
+/* Both ntp_adjtime() and ntp_gettime() return the clock status
+ * which includes leap pending info.  See man ntp_adjtime
+ *
+ * Using ntp_gettime() allows putting a breakpoint on ntp_adjtime()
+ * to make sure we don't trash things if somebody else is taking
+ * care of the clock and we are just the server -- lockclock mode.
+ *
+ * Grump.  musl doesn't have ntp_gettime()
+ * This kludge seems simpler than hacking waf to not build this driver.
+ */
+#ifdef HAVE_NTP_GETTIME
+		struct ntptimeval ntv;
+		ZERO(ntv);
+		switch (ntp_gettime(&ntv)) {
+#else
+		struct timex ntv;
+		ZERO(ntv);
+		switch (ntp_adjtime(&ntv)) {
+#endif
+		case TIME_OK:
+		    pp->leap = LEAP_NOWARNING;
+		    peer->stratum = pp->stratum;
+		    break;
+
+		case TIME_INS:
+		    pp->leap = LEAP_ADDSECOND;
+		    peer->stratum = pp->stratum;
+		    break;
+
+		case TIME_DEL:
+		    pp->leap = LEAP_DELSECOND;
+		    peer->stratum = pp->stratum;
+		    break;
+
+		default:
+		    pp->leap = LEAP_NOTINSYNC;
+		    peer->stratum = STRATUM_UNSPEC;
+		}
+		pp->disp = 0;
+		pp->jitter = 0;
+	} else {
 		pp->leap = LEAP_NOWARNING;
-		peer->stratum = pp->stratum;
-		break;
-
-	case TIME_INS:
-		pp->leap = LEAP_ADDSECOND;
-		peer->stratum = pp->stratum;
-		break;
-
-	case TIME_DEL:
-		pp->leap = LEAP_DELSECOND;
-		peer->stratum = pp->stratum;
-		break;
-
-	default:
-		pp->leap = LEAP_NOTINSYNC;
-		peer->stratum = STRATUM_UNSPEC;
+		pp->disp = DISPERSION;
+		pp->jitter = 0;
 	}
-	pp->disp = 0;
-	pp->jitter = 0;
-#else /* ENABLE_LOCKCLOCK */
-	pp->leap = LEAP_NOWARNING;
-	pp->disp = DISPERSION;
-	pp->jitter = 0;
-#endif /* ENABLE_LOCKCLOCK */
 	pp->lastref = pp->lastrec;
 	refclock_receive(peer);
 }
