@@ -87,9 +87,7 @@
  *
  * MJD, DST, DUT1 and UTC are not used by this driver. The "*" or "#" is
  * the on-time markers echoed by the driver and used by NIST to measure
- * and correct for the propagation delay. Note: the ACTS timecode has
- * recently been changed to eliminate the * on-time indicator. The
- * reason for this and the long term implications are not clear.
+ * and correct for the propagation delay.
  *
  * US Naval Observatory (USNO)
  *
@@ -153,7 +151,7 @@
  * Service identifiers (message length)
  */
 #define REFACTS		"NIST"	/* NIST reference ID */
-#define LENACTS		50	/* NIST format A */
+#define LENACTS		50	/* NIST format */
 #define REFUSNO		"USNO"	/* USNO reference ID */
 #define LENUSNO		20	/* USNO */
 #define REFPTB		"PTB\0"	/* PTB/NPL reference ID */
@@ -785,8 +783,8 @@ modem_timecode(
 		return;
 
 	/*
-	 * ACTS format A: "jjjjj yy-mm-dd hh:mm:ss ds l uuu aaaaa
-	 * UTC(NIST) *".
+	 * ACTS format: "jjjjj yy-mm-dd hh:mm:ss ds l uuu aaaaa UTC(NIST) *".
+	 * The "*" changes to a "#" when the delay correction is valid.
 	 */
 	case LENACTS:
 		if (sscanf(str,
@@ -797,7 +795,7 @@ modem_timecode(
 			refclock_report(peer, CEVNT_BADREPLY);
 			return;
 		}
-		pp->day = ymd2yd(pp->year, month, day);
+		pp->yday = ymd2yd(pp->year, month, day);
 		pp->leap = LEAP_NOWARNING;
 		if (leap == 1)
 			pp->leap = LEAP_ADDSECOND;
@@ -817,7 +815,7 @@ modem_timecode(
 	 */
 	case LENUSNO:
 		if (sscanf(str, "%5lu %3d %2d%2d%2d %3s",
-		    &mjd, &pp->day, &pp->hour, &pp->minute,
+		    &mjd, &pp->yday, &pp->hour, &pp->minute,
 		    &pp->second, utc) != 6) {
 			refclock_report(peer, CEVNT_BADREPLY);
 			return;
@@ -853,7 +851,7 @@ modem_timecode(
 			else if (leapdir == '-')
 				pp->leap = LEAP_DELSECOND;
 		}
-		pp->day = ymd2yd(pp->year, month, day);
+		pp->yday = ymd2yd(pp->year, month, day);
 		memcpy(&pp->refid, REFPTB, REFIDLEN);
 		peer->sstclktype = CTL_SST_TS_TELEPHONE;
 		up->msgcnt++;
@@ -865,7 +863,7 @@ modem_timecode(
 	 */
 	case LENTYPE0:
 		if (sscanf(str, "%c %3d %2d:%2d:%2d %cTZ=%2d",
-		    &synchar, &pp->day, &pp->hour, &pp->minute,
+		    &synchar, &pp->yday, &pp->hour, &pp->minute,
 		    &pp->second, &dstchar, &tz) != 7) {
 			refclock_report(peer, CEVNT_BADREPLY);
 			return;
@@ -883,7 +881,7 @@ modem_timecode(
 	 */
 	case LENTYPE2:
 		if (sscanf(str, "%c%c%2d %3d %2d:%2d:%2d.%3ld%c%c%c",
-		    &synchar, &qualchar, &pp->year, &pp->day,
+		    &synchar, &qualchar, &pp->year, &pp->yday,
 		    &pp->hour, &pp->minute, &pp->second, &pp->nsec,
 		    &dstchar, &leapchar, &dstchar) != 11) {
 			refclock_report(peer, CEVNT_BADREPLY);
@@ -911,7 +909,7 @@ modem_timecode(
 	/*
 	 * We have a valid timecode. The fudge time1 value is added to
 	 * each sample by the main line routines. Note that in current
-	 * telephone networks the propatation time can be different for
+	 * telephone networks the propagation time can be different for
 	 * each call and can reach 200 ms for some calls.
 	 */
 	peer->refid = pp->refid;
