@@ -55,7 +55,6 @@ static void RunAllTests(void)
 	RUN_TEST_GROUP(refidsmear);
 	RUN_TEST_GROUP(socktoa);
 	RUN_TEST_GROUP(statestr);
-	RUN_TEST_GROUP(strtolfp);
 	RUN_TEST_GROUP(timespecops);
 	RUN_TEST_GROUP(vi64ops);
 	RUN_TEST_GROUP(ymd2yd);
@@ -71,12 +70,14 @@ static void RunAllTests(void)
 	RUN_TEST_GROUP(leapsec);
 	RUN_TEST_GROUP(hackrestrict);
 	RUN_TEST_GROUP(recvbuff);
+#ifndef DISABLE_NTS
 	RUN_TEST_GROUP(nts);
 	RUN_TEST_GROUP(nts_client);
 	RUN_TEST_GROUP(nts_server);
 	RUN_TEST_GROUP(nts_cookie);
 	RUN_TEST_GROUP(nts_extens);
 #endif
+#endif
 
 }
 
