@@ -1,3 +1,7 @@
+# Copyright the NTPsec project contributors
+#
+# SPDX-License-Identifier: BSD-2-Clause
+
 from waflib.Configure import conf
 from waflib import Errors
 
@@ -5,7 +9,7 @@ SIZE_FRAG = """
 %s
 #include <stdio.h>
 int main(void) {
-    printf("%%lu", sizeof(%s));
+    printf("%%lu", (unsigned long)sizeof(%s));
     return 0;
 }
 """
@@ -58,7 +62,7 @@ def check_sizeof_cross(ctx, header, sizeof, mandatory=True):
     else:
         ctx.start_msg("Checking sizeof %s" % (sizeof))
 
-    for size in range(2, 13):
+    for size in range(2, 99):
 
         try:
             ctx.check_cc(
@@ -80,6 +84,41 @@ def check_sizeof_cross(ctx, header, sizeof, mandatory=True):
 @conf
 def check_sizeof(*kwargs):
     if kwargs[0].env.ENABLE_CROSS:
-        return check_sizeof_cross(*kwargs)
+        check_sizeof_cross(*kwargs)
     else:
-        return check_sizeof_host(*kwargs)
+        check_sizeof_host(*kwargs)
+
+
+# timex slots are documented as long
+# #if (__TIMESIZE == 64 && __WORDSIZE == 32)
+#    they turn into long long
+# This fails to build in the normal case.
+# So we set NTP_TIMEX_LONG_LONG to 0
+SIZE_FRAG_TIMEX = """
+#include <sys/time.h>    /* for NetBSD */
+#include <sys/timex.h>
+#include <stdio.h>
+int main(void) {
+  struct timex dummy;
+  long long *foo = &dummy.jitter;
+  *foo = 1;  /* supress unused warning */
+  if (*foo) printf("1");
+  return 0;
+}
+"""
+
+def check_timex(ctx):
+    name = "NTP_TIMEX_LONG_LONG"
+    ctx.start_msg("Checking for long long in struct timex" )
+    ctx.check_cc(
+        cflags="-Werror",
+        fragment=SIZE_FRAG_TIMEX,
+        define_name=name,
+        execute=not ctx.env.ENABLE_CROSS,
+        define_ret=True,
+        quote=False,
+        mandatory=False,
+        comment="struct timex has long long"
+    )
+    ctx.end_msg(ctx.get_define(name))
+
