@@ -1,3 +1,7 @@
+# Copyright the NTPsec project contributors
+#
+# SPDX-License-Identifier: BSD-2-Clause
+
 """
 This module exists to contain custom probe functions so they don't clutter
 up the logic in the main configure.py.
@@ -30,7 +34,7 @@ def probe_function(ctx, function, prerequisites, mandatory=False, use=None):
         src += "#include <%s>\n" % hdr
     src += """int main(void) {
         void *p = (void*)(%s);
-        return (int)p;
+        return (int)(long)p;
 }
 """ % function
     have_name = "HAVE_%s" % function.upper()
