@@ -1,6 +1,11 @@
+# Copyright the NTPsec project contributors
+#
+# SPDX-License-Identifier: BSD-2-Clause
+
 from __future__ import print_function
 
 from waflib.Logs import pprint
+from pylib.poly import polystr
 
 
 def test_write_log(ctx):
@@ -15,10 +20,12 @@ def test_write_log(ctx):
         for binary, retval, lines, error in ctx.utest_results:
             fp.write("BINARY      : %s\n" % binary)
             fp.write("RETURN VALUE: %s\n" % retval)
-            fp.write("\n*** stdout ***\n")
-            fp.write(str(lines))
-            fp.write("\n*** stderr ***\n")
-            fp.write(str(error))
+            if lines:
+                fp.write("\n*** stdout ***\n")
+                fp.write(polystr(lines))
+            if error:
+                fp.write("\n*** stderr ***\n")
+                fp.write(polystr(error))
             fp.write("\n\n\n")
 
     pprint("BLUE", "Wrote test log to: ", file_out)
@@ -30,12 +37,17 @@ def test_print_log(ctx):
         pprint("YELLOW", "RETURN VALUE:", retval)
         print("")
 
-        if retval or error:
+        if retval:
             pprint("RED", "****** ERROR ******\n")
+        else:
+            pprint("GREEN", "****** LOG ******\n")
 
-            print(error or lines)
+        if lines:
+            print("\n*** stdout ***\n")
+            print(polystr(lines))
 
-        if (not retval) and (not error):
-            pprint("GREEN", "****** LOG ******\n", lines)
+        if error:
+            print("\n*** stderr ***\n")
+            print(polystr(error))
 
         print("")
