@@ -1,3 +1,7 @@
+# Copyright the NTPsec project contributors
+#
+# SPDX-License-Identifier: BSD-2-Clause
+
 from waflib.Configure import conf
 from waflib.TaskGen import re_m4
 
@@ -41,10 +45,7 @@ def manpage_subst_fun(self, code):
 @conf
 def manpage(ctx, section, source):
 
-    # ctx.install_files('${MANDIR}' + "/man%s/" % section,
-    #                   source.replace("-man.adoc", ".%s" % section))
-
-    if not ctx.env.ENABLE_DOC or ctx.env.DISABLE_MANPAGE:
+    if not ctx.env.BUILD_MAN:
         return
 
     ctx(features="subst",
